@@ -20,7 +20,7 @@
  * Copyright 2005 Sun Microsystems, Inc. All rights reserved.
  */
 /*
- * $Id: DOMUtils.java 1720201 2015-12-15 17:13:17Z coheigea $
+ * $Id$
  */
 package org.apache.jcp.xml.dsig.internal.dom;
 
@@ -40,7 +40,6 @@ import javax.xml.crypto.dsig.spec.*;
 /**
  * Useful static DOM utility methods.
  *
- * @author Sean Mullan
  */
 public final class DOMUtils {
 
@@ -89,7 +88,9 @@ public final class DOMUtils {
     public static Element createElement(Document doc, String tag,
                                         String nsURI, String prefix)
     {
-        return doc.createElementNS(nsURI, getQNameString(prefix, tag));
+        String qName = prefix == null || prefix.length() == 0
+                       ? tag : prefix + ":" + tag;
+        return doc.createElementNS(nsURI, qName);
     }
 
     /**
@@ -332,25 +333,20 @@ public final class DOMUtils {
             this.nl = nl;
         }
 
-        @Override
         public int size() { return nl.getLength(); }
-        @Override
         public Iterator<Node> iterator() {
             return new Iterator<Node>() {
                 private int index;
 
-                @Override
                 public void remove() {
                     throw new UnsupportedOperationException();
                 }
-                @Override
                 public Node next() {
                     if (!hasNext()) {
                         throw new NoSuchElementException();
                     }
                     return nl.item(index++);
                 }
-                @Override
                 public boolean hasNext() {
                     return index < nl.getLength();
                 }
