@@ -20,7 +20,7 @@
  * Copyright 2005 Sun Microsystems, Inc. All rights reserved.
  */
 /*
- * $Id: DOMXPathTransform.java 1720201 2015-12-15 17:13:17Z coheigea $
+ * $Id$
  */
 package org.apache.jcp.xml.dsig.internal.dom;
 
@@ -40,7 +40,6 @@ import org.w3c.dom.NamedNodeMap;
  * DOM-based implementation of XPath Filtering Transform.
  * (Uses Apache XML-Sec Transform implementation)
  *
- * @author Sean Mullan
  */
 public final class DOMXPathTransform extends ApacheTransform {
 
@@ -57,7 +56,6 @@ public final class DOMXPathTransform extends ApacheTransform {
         this.params = params;
     }
 
-    @Override
     public void init(XMLStructure parent, XMLCryptoContext context)
         throws InvalidAlgorithmParameterException
     {
@@ -72,11 +70,11 @@ public final class DOMXPathTransform extends ApacheTransform {
         if (attributes != null) {
             int length = attributes.getLength();
             Map<String, String> namespaceMap =
-                new HashMap<String, String>(length);
+                new HashMap<>((int) Math.ceil(length / 0.75));
             for (int i = 0; i < length; i++) {
                 Attr attr = (Attr)attributes.item(i);
                 String prefix = attr.getPrefix();
-                if (prefix != null && prefix.equals("xmlns")) {
+                if (prefix != null && "xmlns".equals(prefix)) {
                     namespaceMap.put(attr.getLocalName(), attr.getValue());
                 }
             }
@@ -86,7 +84,6 @@ public final class DOMXPathTransform extends ApacheTransform {
         }
     }
 
-    @Override
     public void marshalParams(XMLStructure parent, XMLCryptoContext context)
         throws MarshalException
     {
