@@ -42,6 +42,7 @@ import org.apache.xml.security.utils.UnsyncByteArrayOutputStream;
 import org.apache.xml.security.utils.XMLUtils;
 import org.w3c.dom.Attr;
 import org.w3c.dom.Comment;
+import org.w3c.dom.DOMException;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;
@@ -51,12 +52,14 @@ import org.xml.sax.SAXException;
 
 /**
  * Abstract base class for canonicalization algorithms.
- *
- * @author Christian Geuer-Pollmann <geuerp@apache.org>
+ * Please note that these implementations are NOT thread safe - please see the following JIRA for more information:
+ * https://issues.apache.org/jira/browse/SANTUARIO-463
  */
 public abstract class CanonicalizerBase extends CanonicalizerSpi {
     public static final String XML = "xml";
     public static final String XMLNS = "xmlns";
+    public static final String XMLNS_URI = Constants.NamespaceSpecNS;
+    public static final String XML_LANG_URI = Constants.XML_LANG_SPACE_SpecNS;
 
     protected static final AttrCompare COMPARE = new AttrCompare();
 
@@ -108,7 +111,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
 
     /**
      * Method engineCanonicalizeSubTree
-     * @inheritDoc
+     * {@inheritDoc}
      * @param rootNode
      * @throws CanonicalizationException
      */
@@ -119,7 +122,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
 
     /**
      * Method engineCanonicalizeXPathNodeSet
-     * @inheritDoc
+     * {@inheritDoc}
      * @param xpathNodeSet
      * @throws CanonicalizationException
      */
@@ -173,6 +176,10 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
         this.writer = writer;
     }
 
+    protected OutputStream getWriter() {
+        return writer;
+    }
+
     /**
      * Canonicalizes a Subtree node.
      *
@@ -241,11 +248,11 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
             return;
         }
         Node sibling = null;
-        Node parentNode = null;    	
+        Node parentNode = null;
         final OutputStream writer = this.writer;
         final Node excludeNode = this.excludeNode;
         final boolean includeComments = this.includeComments;
-        Map<String, byte[]> cache = new HashMap<String, byte[]>();
+        Map<String, byte[]> cache = new HashMap<>();
         do {
             switch (currentNode.getNodeType()) {
 
@@ -289,14 +296,8 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
                 String name = currentElement.getTagName();
                 UtfHelpper.writeByte(name, writer, cache);
 
-                Iterator<Attr> attrs = this.handleAttributesSubtree(currentElement, ns);
-                if (attrs != null) {
-                    //we output all Attrs which are available
-                    while (attrs.hasNext()) {
-                        Attr attr = attrs.next();
-                        outputAttrToWriter(attr.getNodeName(), attr.getNodeValue(), writer, cache);
-                    }
-                }
+                outputAttributesSubtree(currentElement, ns, cache);
+
                 writer.write('>');
                 sibling = currentNode.getFirstChild();
                 if (sibling == null) {
@@ -317,7 +318,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
             default :
                 break;
             }
-            while (sibling == null && parentNode != null) {    		      		      			
+            while (sibling == null && parentNode != null) {
                 writer.write(END_TAG.clone());
                 UtfHelpper.writeByte(((Element)parentNode).getTagName(), writer, cache);
                 writer.write('>');
@@ -331,7 +332,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
                 if (parentNode == null || Node.ELEMENT_NODE != parentNode.getNodeType()) {
                     documentLevel = NODE_AFTER_DOCUMENT_ELEMENT;
                     parentNode = null;
-                }    			
+                }
             }
             if (sibling == null) {
                 return;
@@ -388,7 +389,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
         if (isVisibleInt(currentNode) == -1) {
             return;
         }
-        boolean currentNodeIsVisible = false;	
+        boolean currentNodeIsVisible = false;
         NameSpaceSymbTable ns = new NameSpaceSymbTable();
         if (currentNode != null && Node.ELEMENT_NODE == currentNode.getNodeType()) {
             getParentNameSpaces((Element)currentNode, ns);
@@ -397,10 +398,9 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
             return;
         }
         Node sibling = null;
-        Node parentNode = null;	
-        OutputStream writer = this.writer;
+        Node parentNode = null;
         int documentLevel = NODE_BEFORE_DOCUMENT_ELEMENT;
-        Map<String, byte[]> cache = new HashMap<String, byte[]>();
+        Map<String, byte[]> cache = new HashMap<>();
         do {
             switch (currentNode.getNodeType()) {
 
@@ -417,7 +417,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
                 sibling = currentNode.getFirstChild();
                 break;
 
-            case Node.COMMENT_NODE :			
+            case Node.COMMENT_NODE :
                 if (this.includeComments && isVisibleDO(currentNode, ns.getLevel()) == 1) {
                     outputCommentToWriter((Comment) currentNode, writer, documentLevel);
                 }
@@ -464,14 +464,8 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
                     ns.push();
                 }
 
-                Iterator<Attr> attrs = handleAttributes(currentElement,ns);
-                if (attrs != null) {
-                    //we output all Attrs which are available
-                    while (attrs.hasNext()) {
-                        Attr attr = attrs.next();
-                        outputAttrToWriter(attr.getNodeName(), attr.getNodeValue(), writer, cache);
-                    }
-                }
+                outputAttributes(currentElement, ns, cache);
+
                 if (currentNodeIsVisible) {
                     writer.write('>');
                 }
@@ -486,13 +480,13 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
                         ns.outputNodePop();
                     } else {
                         ns.pop();
-                    }				
+                    }
                     if (parentNode != null) {
                         sibling = currentNode.getNextSibling();
                     }
                 } else {
                     parentNode = currentElement;
-                }			
+                }
                 break;
 
             case Node.DOCUMENT_TYPE_NODE :
@@ -517,7 +511,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
                 if (parentNode == null || Node.ELEMENT_NODE != parentNode.getNodeType()) {
                     parentNode = null;
                     documentLevel = NODE_AFTER_DOCUMENT_ELEMENT;
-                }    			
+                }
             }
             if (sibling == null) {
                 return;
@@ -530,7 +524,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
     protected int isVisibleDO(Node currentNode, int level) {
         if (nodeFilter != null) {
             Iterator<NodeFilter> it = nodeFilter.iterator();
-            while (it.hasNext()) {   	
+            while (it.hasNext()) {
                 int i = it.next().isNodeIncludeDO(currentNode, level);
                 if (i != 1) {
                     return i;
@@ -546,7 +540,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
     protected int isVisibleInt(Node currentNode) {
         if (nodeFilter != null) {
             Iterator<NodeFilter> it = nodeFilter.iterator();
-            while (it.hasNext()) {   			
+            while (it.hasNext()) {
                 int i = it.next().isNodeInclude(currentNode);
                 if (i != 1) {
                     return i;
@@ -562,7 +556,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
     protected boolean isVisible(Node currentNode) {
         if (nodeFilter != null) {
             Iterator<NodeFilter> it = nodeFilter.iterator();
-            while (it.hasNext()) {   			
+            while (it.hasNext()) {
                 if (it.next().isNodeInclude(currentNode) != 1) {
                     return false;
                 }
@@ -617,7 +611,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
             return;
         }
         //Obtain all the parents of the element
-        List<Element> parents = new ArrayList<Element>();
+        List<Element> parents = new ArrayList<>();
         Node parent = n1;
         while (parent != null && Node.ELEMENT_NODE == parent.getNodeType()) {
             parents.add((Element)parent);
@@ -638,26 +632,26 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
     }
 
     /**
-     * Obtain the attributes to output for this node in XPathNodeSet c14n.
+     * Output the attributes for this node in XPathNodeSet c14n.
      *
      * @param element
      * @param ns
-     * @return the attributes nodes to output.
-     * @throws CanonicalizationException
+     * @param cache
+     * @throws CanonicalizationException, DOMException, IOException
      */
-    abstract Iterator<Attr> handleAttributes(Element element, NameSpaceSymbTable ns)
-        throws CanonicalizationException;
+    abstract void outputAttributes(Element element, NameSpaceSymbTable ns, Map<String, byte[]> cache)
+        throws CanonicalizationException, DOMException, IOException;
 
     /**
-     * Obtain the attributes to output for this node in a Subtree c14n.
+     * Output the attributes for this node in a Subtree c14n.
      *
      * @param element
      * @param ns
-     * @return the attributes nodes to output.
-     * @throws CanonicalizationException
+     * @param cache
+     * @throws CanonicalizationException, DOMException, IOException
      */
-    abstract Iterator<Attr> handleAttributesSubtree(Element element, NameSpaceSymbTable ns)
-        throws CanonicalizationException;
+    abstract void outputAttributesSubtree(Element element, NameSpaceSymbTable ns, Map<String, byte[]> cache)
+        throws CanonicalizationException, DOMException, IOException;
 
     abstract void circumventBugIfNeeded(XMLSignatureInput input)
         throws CanonicalizationException, ParserConfigurationException, IOException, SAXException;
@@ -667,8 +661,8 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
      *
      * The string value of the node is modified by replacing
      * <UL>
-     * <LI>all ampersands (&) with <CODE>&amp;amp;</CODE></LI>
-     * <LI>all open angle brackets (<) with <CODE>&amp;lt;</CODE></LI>
+     * <LI>all ampersands with <CODE>&amp;amp;</CODE></LI>
+     * <LI>all open angle brackets with <CODE>&amp;lt;</CODE></LI>
      * <LI>all quotation mark characters with <CODE>&amp;quot;</CODE></LI>
      * <LI>and the whitespace characters <CODE>#x9</CODE>, #xA, and #xD, with character
      * references. The character references are written in uppercase
@@ -744,7 +738,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
      */
     protected void outputPItoWriter(
         ProcessingInstruction currentPI, OutputStream writer, int position
-    ) throws IOException {   	
+    ) throws IOException {
         if (position == NODE_AFTER_DOCUMENT_ELEMENT) {
             writer.write('\n');
         }
@@ -800,7 +794,7 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
      */
     protected void outputCommentToWriter(
         Comment currentComment, OutputStream writer, int position
-    ) throws IOException {   	
+    ) throws IOException {
         if (position == NODE_AFTER_DOCUMENT_ELEMENT) {
             writer.write('\n');
         }
