@@ -22,6 +22,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.UnsupportedEncodingException;
+import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -48,7 +49,7 @@ public abstract class AbstractSerializer implements Serializer {
     /**
      * Returns a <code>String</code> representation of the specified
      * <code>Element</code>.
-     * <p/>
+     * <p></p>
      * Refer also to comments about setup of format.
      *
      * @param element the <code>Element</code> to serialize.
@@ -76,18 +77,18 @@ public abstract class AbstractSerializer implements Serializer {
     /**
      * Returns a <code>String</code> representation of the specified
      * <code>NodeList</code>.
-     * <p/>
+     * <p></p>
      * This is a special case because the NodeList may represent a
      * <code>DocumentFragment</code>. A document fragment may be a
      * non-valid XML document (refer to appropriate description of
      * W3C) because it my start with a non-element node, e.g. a text
      * node.
-     * <p/>
+     * <p></p>
      * The methods first converts the node list into a document fragment.
      * Special care is taken to not destroy the current document, thus
      * the method clones the nodes (deep cloning) before it appends
      * them to the document fragment.
-     * <p/>
+     * <p></p>
      * Refer also to comments about setup of format.
      *
      * @param content the <code>NodeList</code> to serialize.
@@ -96,16 +97,17 @@ public abstract class AbstractSerializer implements Serializer {
      * @throws Exception
      */
     public String serialize(NodeList content) throws Exception {
-        ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        canon.setSecureValidation(secureValidation);
-        canon.setWriter(baos);
-        canon.notReset();
-        for (int i = 0; i < content.getLength(); i++) {
-            canon.canonicalizeSubtree(content.item(i));
+        try (ByteArrayOutputStream baos = new ByteArrayOutputStream()) {
+            canon.setSecureValidation(secureValidation);
+            canon.setWriter(baos);
+            canon.notReset();
+            for (int i = 0; i < content.getLength(); i++) {
+                canon.canonicalizeSubtree(content.item(i));
+            }
+            String ret = baos.toString(StandardCharsets.UTF_8.name());
+            baos.reset();
+            return ret;
         }
-        String ret = baos.toString("UTF-8");
-        baos.reset();
-        return ret;
     }
 
     /**
@@ -118,14 +120,15 @@ public abstract class AbstractSerializer implements Serializer {
      * @throws Exception
      */
     public byte[] serializeToByteArray(NodeList content) throws Exception {
-        ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        canon.setSecureValidation(secureValidation);
-        canon.setWriter(baos);
-        canon.notReset();
-        for (int i = 0; i < content.getLength(); i++) {
-            canon.canonicalizeSubtree(content.item(i));
+        try (ByteArrayOutputStream baos = new ByteArrayOutputStream()) {
+            canon.setSecureValidation(secureValidation);
+            canon.setWriter(baos);
+            canon.notReset();
+            for (int i = 0; i < content.getLength(); i++) {
+                canon.canonicalizeSubtree(content.item(i));
+            }
+            return baos.toByteArray();
         }
-        return baos.toByteArray();
     }
 
     /**
@@ -135,14 +138,15 @@ public abstract class AbstractSerializer implements Serializer {
      * @throws Exception
      */
     public String canonSerialize(Node node) throws Exception {
-        ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        canon.setSecureValidation(secureValidation);
-        canon.setWriter(baos);
-        canon.notReset();
-        canon.canonicalizeSubtree(node);
-        String ret = baos.toString("UTF-8");
-        baos.reset();
-        return ret;
+        try (ByteArrayOutputStream baos = new ByteArrayOutputStream()) {
+            canon.setSecureValidation(secureValidation);
+            canon.setWriter(baos);
+            canon.notReset();
+            canon.canonicalizeSubtree(node);
+            String ret = baos.toString(StandardCharsets.UTF_8.name());
+            baos.reset();
+            return ret;
+        }
     }
 
     /**
@@ -152,12 +156,13 @@ public abstract class AbstractSerializer implements Serializer {
      * @throws Exception
      */
     public byte[] canonSerializeToByteArray(Node node) throws Exception {
-        ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        canon.setSecureValidation(secureValidation);
-        canon.setWriter(baos);
-        canon.notReset();
-        canon.canonicalizeSubtree(node);
-        return baos.toByteArray();
+        try (ByteArrayOutputStream baos = new ByteArrayOutputStream()) {
+            canon.setSecureValidation(secureValidation);
+            canon.setWriter(baos);
+            canon.notReset();
+            canon.canonicalizeSubtree(node);
+            return baos.toByteArray();
+        }
     }
 
     /**
@@ -174,17 +179,16 @@ public abstract class AbstractSerializer implements Serializer {
      * @return the Node resulting from the parse of the source
      * @throws XMLEncryptionException
      */
-    public abstract Node deserialize(byte[] source, Node ctx) throws XMLEncryptionException;
+    public abstract Node deserialize(byte[] source, Node ctx) throws XMLEncryptionException, IOException;
 
     protected static byte[] createContext(byte[] source, Node ctx) throws XMLEncryptionException {
         // Create the context to parse the document against
-        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
-        try {
-            OutputStreamWriter outputStreamWriter = new OutputStreamWriter(byteArrayOutputStream, "UTF-8");
+        try (ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream()) {
+            OutputStreamWriter outputStreamWriter = new OutputStreamWriter(byteArrayOutputStream, StandardCharsets.UTF_8);
             outputStreamWriter.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?><dummy");
 
             // Run through each node up to the document node and find any xmlns: nodes
-            Map<String, String> storedNamespaces = new HashMap<String, String>();
+            Map<String, String> storedNamespaces = new HashMap<>();
             Node wk = ctx;
             while (wk != null) {
                 NamedNodeMap atts = wk.getAttributes();
@@ -192,7 +196,7 @@ public abstract class AbstractSerializer implements Serializer {
                     for (int i = 0; i < atts.getLength(); ++i) {
                         Node att = atts.item(i);
                         String nodeName = att.getNodeName();
-                        if ((nodeName.equals("xmlns") || nodeName.startsWith("xmlns:"))
+                        if (("xmlns".equals(nodeName) || nodeName.startsWith("xmlns:"))
                                 && !storedNamespaces.containsKey(att.getNodeName())) {
                             outputStreamWriter.write(" ");
                             outputStreamWriter.write(nodeName);
@@ -226,7 +230,7 @@ public abstract class AbstractSerializer implements Serializer {
         sb.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?><dummy");
 
         // Run through each node up to the document node and find any xmlns: nodes
-        Map<String, String> storedNamespaces = new HashMap<String, String>();
+        Map<String, String> storedNamespaces = new HashMap<>();
         Node wk = ctx;
         while (wk != null) {
             NamedNodeMap atts = wk.getAttributes();
@@ -234,7 +238,7 @@ public abstract class AbstractSerializer implements Serializer {
                 for (int i = 0; i < atts.getLength(); ++i) {
                     Node att = atts.item(i);
                     String nodeName = att.getNodeName();
-                    if ((nodeName.equals("xmlns") || nodeName.startsWith("xmlns:"))
+                    if (("xmlns".equals(nodeName) || nodeName.startsWith("xmlns:"))
                         && !storedNamespaces.containsKey(att.getNodeName())) {
                         sb.append(" ");
                         sb.append(nodeName);
