@@ -31,7 +31,7 @@ import org.w3c.dom.Element;
 
 public class DSAKeyValueResolver extends KeyResolverSpi {
 
-    private static org.slf4j.Logger log =
+    private static final org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(DSAKeyValueResolver.class);
 
 
@@ -52,14 +52,14 @@ public class DSAKeyValueResolver extends KeyResolverSpi {
         Element dsaKeyElement = null;
         boolean isKeyValue =
             XMLUtils.elementIsInSignatureSpace(element, Constants._TAG_KEYVALUE);
-        if (isKeyValue) {         	
+        if (isKeyValue) {
             dsaKeyElement =
                 XMLUtils.selectDsNode(element.getFirstChild(), Constants._TAG_DSAKEYVALUE, 0);
         } else if (XMLUtils.elementIsInSignatureSpace(element, Constants._TAG_DSAKEYVALUE)) {
             // this trick is needed to allow the RetrievalMethodResolver to eat a
             // ds:DSAKeyValue directly (without KeyValue)
             dsaKeyElement = element;
-        }	
+        }
 
         if (dsaKeyElement == null) {
             return null;
@@ -71,9 +71,7 @@ public class DSAKeyValueResolver extends KeyResolverSpi {
 
             return pk;
         } catch (XMLSecurityException ex) {
-            if (log.isDebugEnabled()) {
-                log.debug(ex.getMessage(), ex);
-            }
+            LOG.debug(ex.getMessage(), ex);
             //do nothing
         }
 
@@ -81,14 +79,14 @@ public class DSAKeyValueResolver extends KeyResolverSpi {
     }
 
 
-    /** @inheritDoc */
+    /** {@inheritDoc} */
     public X509Certificate engineLookupResolveX509Certificate(
         Element element, String baseURI, StorageResolver storage
     ) {
         return null;
     }
 
-    /** @inheritDoc */
+    /** {@inheritDoc} */
     public javax.crypto.SecretKey engineLookupAndResolveSecretKey(
         Element element, String baseURI, StorageResolver storage
     ) {
