@@ -35,7 +35,7 @@ import org.w3c.dom.Element;
 
 public class X509SubjectNameResolver extends KeyResolverSpi {
 
-    private static org.slf4j.Logger log =
+    private static final org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(X509SubjectNameResolver.class);
 
 
@@ -64,7 +64,7 @@ public class X509SubjectNameResolver extends KeyResolverSpi {
 
     /**
      * Method engineResolveX509Certificate
-     * @inheritDoc
+     * {@inheritDoc}
      * @param element
      * @param baseURI
      * @param storage
@@ -74,25 +74,19 @@ public class X509SubjectNameResolver extends KeyResolverSpi {
     public X509Certificate engineLookupResolveX509Certificate(
         Element element, String baseURI, StorageResolver storage
     ) throws KeyResolverException {
-        if (log.isDebugEnabled()) {
-            log.debug("Can I resolve " + element.getTagName() + "?");
-        }
-        Element[] x509childNodes = null;	
+        LOG.debug("Can I resolve {}?", element.getTagName());
+        Element[] x509childNodes = null;
         XMLX509SubjectName x509childObject[] = null;
 
         if (!XMLUtils.elementIsInSignatureSpace(element, Constants._TAG_X509DATA)) {
-            if (log.isDebugEnabled()) {
-                log.debug("I can't");
-            }
+            LOG.debug("I can't");
             return null;
         }
         x509childNodes =
             XMLUtils.selectDsNodes(element.getFirstChild(), Constants._TAG_X509SUBJECTNAME);
 
         if (!(x509childNodes != null && x509childNodes.length > 0)) {
-            if (log.isDebugEnabled()) {
-                log.debug("I can't");
-            }
+            LOG.debug("I can't");
             return null;
         }
 
@@ -102,9 +96,7 @@ public class X509SubjectNameResolver extends KeyResolverSpi {
                 KeyResolverException ex =
                     new KeyResolverException("KeyResolver.needStorageResolver", exArgs);
 
-                if (log.isDebugEnabled()) {
-                    log.debug("", ex);
-                }
+                LOG.debug("", ex);
 
                 throw ex;
             }
@@ -121,34 +113,23 @@ public class X509SubjectNameResolver extends KeyResolverSpi {
                 XMLX509SubjectName certSN =
                     new XMLX509SubjectName(element.getOwnerDocument(), cert);
 
-                if (log.isDebugEnabled()) {
-                    log.debug("Found Certificate SN: " + certSN.getSubjectName());
-                }
+                LOG.debug("Found Certificate SN: {}", certSN.getSubjectName());
 
                 for (int i = 0; i < x509childObject.length; i++) {
-                    if (log.isDebugEnabled()) {
-                        log.debug("Found Element SN:     "
-                              + x509childObject[i].getSubjectName());
-                    }
+                    LOG.debug("Found Element SN:     {}", x509childObject[i].getSubjectName());
 
                     if (certSN.equals(x509childObject[i])) {
-                        if (log.isDebugEnabled()) {
-                            log.debug("match !!! ");
-                        }
+                        LOG.debug("match !!! ");
 
                         return cert;
                     }
-                    if (log.isDebugEnabled()) {
-                        log.debug("no match...");
-                    }
+                    LOG.debug("no match...");
                 }
             }
 
             return null;
         } catch (XMLSecurityException ex) {
-            if (log.isDebugEnabled()) {
-                log.debug("XMLSecurityException", ex);
-            }
+            LOG.debug("XMLSecurityException", ex);
 
             throw new KeyResolverException(ex);
         }
@@ -156,7 +137,7 @@ public class X509SubjectNameResolver extends KeyResolverSpi {
 
     /**
      * Method engineResolveSecretKey
-     * @inheritDoc
+     * {@inheritDoc}
      * @param element
      * @param baseURI
      * @param storage
