@@ -30,12 +30,10 @@ import org.apache.xml.security.algorithms.SignatureAlgorithm;
 import org.apache.xml.security.c14n.CanonicalizationException;
 import org.apache.xml.security.c14n.Canonicalizer;
 import org.apache.xml.security.c14n.InvalidCanonicalizerException;
-import org.apache.xml.security.exceptions.Base64DecodingException;
 import org.apache.xml.security.exceptions.XMLSecurityException;
 import org.apache.xml.security.keys.KeyInfo;
 import org.apache.xml.security.keys.content.X509Data;
 import org.apache.xml.security.transforms.Transforms;
-import org.apache.xml.security.utils.Base64;
 import org.apache.xml.security.utils.Constants;
 import org.apache.xml.security.utils.I18n;
 import org.apache.xml.security.utils.SignatureElementProxy;
@@ -200,7 +198,7 @@ public final class XMLSignature extends SignatureElementProxy {
     public static final String ALGO_ID_SIGNATURE_ECDSA_RIPEMD160 =
         "http://www.w3.org/2007/05/xmldsig-more#ecdsa-ripemd160";
 
-    private static org.slf4j.Logger log =
+    private static final org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(XMLSignature.class);
 
     /** ds:Signature.ds:SignedInfo element */
@@ -377,7 +375,7 @@ public final class XMLSignature extends SignatureElementProxy {
      */
     public XMLSignature(Element element, String baseURI)
         throws XMLSignatureException, XMLSecurityException {
-        this(element, baseURI, false);
+        this(element, baseURI, true);
     }
 
     /**
@@ -394,12 +392,20 @@ public final class XMLSignature extends SignatureElementProxy {
         throws XMLSignatureException, XMLSecurityException {
         super(element, baseURI);
 
+        if (!(Constants.SignatureSpecNS.equals(element.getNamespaceURI())
+            && Constants._TAG_SIGNATURE.equals(element.getLocalName()))) {
+            Object[] exArgs = { element.getLocalName() };
+            throw new XMLSignatureException("signature.Verification.InvalidElement", exArgs);
+        }
+
         // check out SignedInfo child
         Element signedInfoElem = XMLUtils.getNextElement(element.getFirstChild());
 
         // check to see if it is there
-        if (signedInfoElem == null) {
-            Object exArgs[] = { Constants._TAG_SIGNEDINFO, Constants._TAG_SIGNATURE };
+        if (signedInfoElem == null ||
+            !(Constants.SignatureSpecNS.equals(signedInfoElem.getNamespaceURI())
+                && Constants._TAG_SIGNEDINFO.equals(signedInfoElem.getLocalName()))) {
+            Object[] exArgs = { Constants._TAG_SIGNEDINFO, Constants._TAG_SIGNATURE };
             throw new XMLSignatureException("xml.WrongContent", exArgs);
         }
 
@@ -413,8 +419,10 @@ public final class XMLSignature extends SignatureElementProxy {
             XMLUtils.getNextElement(signedInfoElem.getNextSibling());
 
         // check to see if it exists
-        if (signatureValueElement == null) {
-            Object exArgs[] = { Constants._TAG_SIGNATUREVALUE, Constants._TAG_SIGNATURE };
+        if (signatureValueElement == null ||
+            !(Constants.SignatureSpecNS.equals(signatureValueElement.getNamespaceURI())
+                && Constants._TAG_SIGNATUREVALUE.equals(signatureValueElement.getLocalName()))) {
+            Object[] exArgs = { Constants._TAG_SIGNATUREVALUE, Constants._TAG_SIGNATURE };
             throw new XMLSignatureException("xml.WrongContent", exArgs);
         }
         Attr signatureValueAttr = signatureValueElement.getAttributeNodeNS(null, "Id");
@@ -427,17 +435,27 @@ public final class XMLSignature extends SignatureElementProxy {
             XMLUtils.getNextElement(signatureValueElement.getNextSibling());
 
         // If it exists use it, but it's not mandatory
+        Element objectElem = null;
         if (keyInfoElem != null
             && Constants.SignatureSpecNS.equals(keyInfoElem.getNamespaceURI())
             && Constants._TAG_KEYINFO.equals(keyInfoElem.getLocalName())) {
             this.keyInfo = new KeyInfo(keyInfoElem, baseURI);
             this.keyInfo.setSecureValidation(secureValidation);
+            objectElem = XMLUtils.getNextElement(keyInfoElem.getNextSibling());
+        } else {
+            // If we have no KeyInfo
+            objectElem = keyInfoElem;
         }
 
         // <element ref="ds:Object" minOccurs="0" maxOccurs="unbounded"/>
-        Element objectElem =
-            XMLUtils.getNextElement(signatureValueElement.getNextSibling());
         while (objectElem != null) {
+            // Make sure it actually is an Object
+            if (!(Constants.SignatureSpecNS.equals(objectElem.getNamespaceURI())
+                && Constants._TAG_OBJECT.equals(objectElem.getLocalName()))) {
+                Object[] exArgs = { objectElem.getLocalName() };
+                throw new XMLSignatureException("signature.Verification.InvalidElement", exArgs);
+            }
+
             Attr objectAttr = objectElem.getAttributeNodeNS(null, "Id");
             if (objectAttr != null) {
                 objectElem.setIdAttributeNode(objectAttr, true);
@@ -449,9 +467,9 @@ public final class XMLSignature extends SignatureElementProxy {
                 if (firstChild.getNodeType() == Node.ELEMENT_NODE) {
                     Element childElem = (Element)firstChild;
                     String tag = childElem.getLocalName();
-                    if (tag.equals("Manifest")) {
+                    if ("Manifest".equals(tag)) {
                         new Manifest(childElem, baseURI);
-                    } else if (tag.equals("SignatureProperties")) {
+                    } else if ("SignatureProperties".equals(tag)) {
                         new SignatureProperties(childElem, baseURI);
                     }
                 }
@@ -501,11 +519,8 @@ public final class XMLSignature extends SignatureElementProxy {
      * @throws XMLSignatureException If there is no content
      */
     public byte[] getSignatureValue() throws XMLSignatureException {
-        try {
-            return Base64.decode(signatureValueElement);
-        } catch (Base64DecodingException ex) {
-            throw new XMLSignatureException(ex, "empty");
-        }
+        String content = XMLUtils.getFullTextChildrenFromNode(signatureValueElement);
+        return XMLUtils.decode(content);
     }
 
     /**
@@ -520,7 +535,7 @@ public final class XMLSignature extends SignatureElementProxy {
             signatureValueElement.removeChild(signatureValueElement.getFirstChild());
         }
 
-        String base64codedValue = Base64.encode(bytes);
+        String base64codedValue = XMLUtils.encodeToString(bytes);
 
         if (base64codedValue.length() > 76 && !XMLUtils.ignoreLineBreaks()) {
             base64codedValue = "\n" + base64codedValue + "\n";
@@ -589,11 +604,11 @@ public final class XMLSignature extends SignatureElementProxy {
     }
 
     /**
-     * Returns the <code>i<code>th <code>ds:Object</code> child of the signature
+     * Returns the <code>i</code>th <code>ds:Object</code> child of the signature
      * or null if no such <code>ds:Object</code> element exists.
      *
      * @param i
-     * @return the <code>i<code>th <code>ds:Object</code> child of the signature
+     * @return the <code>i</code>th <code>ds:Object</code> child of the signature
      * or null if no such <code>ds:Object</code> element exists.
      */
     public ObjectContainer getObjectItem(int i) {
@@ -634,34 +649,20 @@ public final class XMLSignature extends SignatureElementProxy {
             );
         }
 
-        try {
-            //Create a SignatureAlgorithm object
-            SignedInfo si = this.getSignedInfo();
-            SignatureAlgorithm sa = si.getSignatureAlgorithm();
-            OutputStream so = null;
-            try {
-                // generate digest values for all References in this SignedInfo
-                si.generateDigestValues();
+        //Create a SignatureAlgorithm object
+        SignedInfo si = this.getSignedInfo();
+        SignatureAlgorithm sa = si.getSignatureAlgorithm();
+        try (SignerOutputStream output = new SignerOutputStream(sa);
+            OutputStream so = new UnsyncBufferedOutputStream(output)) {
 
-                // initialize SignatureAlgorithm for signing
-                sa.initSign(signingKey);
+            // generate digest values for all References in this SignedInfo
+            si.generateDigestValues();
 
-                so = new UnsyncBufferedOutputStream(new SignerOutputStream(sa));
-                // get the canonicalized bytes from SignedInfo
-                si.signInOctetStream(so);
-            } catch (XMLSecurityException ex) {
-                throw ex;
-            } finally {
-                if (so != null) {
-                    try {
-                        so.close();
-                    } catch (IOException ex) {
-                        if (log.isDebugEnabled()) {
-                            log.debug(ex.getMessage(), ex);
-                        }
-                    }
-                }
-            }
+            // initialize SignatureAlgorithm for signing
+            sa.initSign(signingKey);
+
+            // get the canonicalized bytes from SignedInfo
+            si.signInOctetStream(so);
 
             // set them on the SignatureValue element
             this.setSignatureValueElement(sa.sign());
@@ -673,6 +674,8 @@ public final class XMLSignature extends SignatureElementProxy {
             throw new XMLSignatureException(ex);
         } catch (XMLSecurityException ex) {
             throw new XMLSignatureException(ex);
+        } catch (IOException ex) {
+            throw new XMLSignatureException(ex);
         }
     }
 
@@ -744,28 +747,23 @@ public final class XMLSignature extends SignatureElementProxy {
             //create a SignatureAlgorithms from the SignatureMethod inside
             //SignedInfo. This is used to validate the signature.
             SignatureAlgorithm sa = si.getSignatureAlgorithm();
-            if (log.isDebugEnabled()) {
-                log.debug("signatureMethodURI = " + sa.getAlgorithmURI());
-                log.debug("jceSigAlgorithm    = " + sa.getJCEAlgorithmString());
-                log.debug("jceSigProvider     = " + sa.getJCEProviderName());
-                log.debug("PublicKey = " + pk);
-            }
+            LOG.debug("signatureMethodURI = {}", sa.getAlgorithmURI());
+            LOG.debug("jceSigAlgorithm = {}", sa.getJCEAlgorithmString());
+            LOG.debug("PublicKey = {}", pk);
+
             byte sigBytes[] = null;
-            try {
+            try (SignerOutputStream so = new SignerOutputStream(sa);
+                OutputStream bos = new UnsyncBufferedOutputStream(so)) {
+
                 sa.initVerify(pk);
+                LOG.debug("jceSigProvider = {}", sa.getJCEProviderName());
 
                 // Get the canonicalized (normalized) SignedInfo
-                SignerOutputStream so = new SignerOutputStream(sa);
-                OutputStream bos = new UnsyncBufferedOutputStream(so);
-
                 si.signInOctetStream(bos);
-                bos.close();
                 // retrieve the byte[] from the stored signature
                 sigBytes = this.getSignatureValue();
             } catch (IOException ex) {
-                if (log.isDebugEnabled()) {
-                    log.debug(ex.getMessage(), ex);
-                }
+                LOG.debug(ex.getMessage(), ex);
                 // Impossible...
             } catch (XMLSecurityException ex) {
                 throw ex;
@@ -774,7 +772,7 @@ public final class XMLSignature extends SignatureElementProxy {
             // have SignatureAlgorithm sign the input bytes and compare them to
             // the bytes that were stored in the signature.
             if (!sa.verify(sigBytes)) {
-                log.warn("Signature verification failed.");
+                LOG.warn("Signature verification failed.");
                 return false;
             }
 
