@@ -40,14 +40,12 @@ import java.util.List;
 /**
  * Custom XMLStreamWriter to map XMLStreamWriter method calls into XMLEvent's
  *
- * @author $Author: coheigea $
- * @version $Revision: 1770671 $ $Date: 2016-11-21 13:15:36 +0100 (Mon, 21 Nov 2016) $
  */
 public class XMLSecurityStreamWriter implements XMLStreamWriter {
 
     private final OutputProcessorChain outputProcessorChain;
-    private Element elementStack = null;
-    private Element openStartElement = null;
+    private Element elementStack;
+    private Element openStartElement;
     private NSContext namespaceContext = new NSContext(null);
     private boolean endDocumentWritten = false;
     private boolean haveToWriteEndElement = false;
@@ -268,7 +266,7 @@ public class XMLSecurityStreamWriter implements XMLStreamWriter {
     @Override
     public void writeDTD(String dtd) throws XMLStreamException {
         if (elementStack != null) {
-            throw new XMLStreamException("Not in prolog");
+            throw new XMLStreamException("Not in proLOG");
         }
         chainProcessEvent(XMLSecEventFactory.createXMLSecDTD(dtd));
     }
@@ -443,7 +441,7 @@ public class XMLSecurityStreamWriter implements XMLStreamWriter {
 
         private void addNamespace(XMLSecNamespace namespace) {
             if (this.namespaces == Collections.<XMLSecNamespace>emptyList()) {
-                this.namespaces = new ArrayList<XMLSecNamespace>(1);
+                this.namespaces = new ArrayList<>(1);
             }
             this.namespaces.add(namespace);
 
@@ -457,7 +455,7 @@ public class XMLSecurityStreamWriter implements XMLStreamWriter {
 
         private void addAttribute(XMLSecAttribute attribute) {
             if (this.attributes == Collections.<XMLSecAttribute>emptyList()) {
-                this.attributes = new ArrayList<XMLSecAttribute>(1);
+                this.attributes = new ArrayList<>(1);
             }
             this.attributes.add(attribute);
         }
@@ -525,7 +523,7 @@ public class XMLSecurityStreamWriter implements XMLStreamWriter {
         @SuppressWarnings("rawtypes")
         @Override
         public Iterator getPrefixes(String namespaceURI) {
-            List<String> prefixes = new ArrayList<String>(1);
+            List<String> prefixes = new ArrayList<>(1);
             for (int i = 1; i < prefixNsList.size(); i += 2) {
                 String s = prefixNsList.get(i);
                 if (s.equals(namespaceURI)) {
@@ -545,7 +543,7 @@ public class XMLSecurityStreamWriter implements XMLStreamWriter {
 
         private void add(String prefix, String namespace) {
             if (this.prefixNsList == Collections.<String>emptyList()) {
-                this.prefixNsList = new ArrayList<String>(1);
+                this.prefixNsList = new ArrayList<>(1);
             }
             this.prefixNsList.add(prefix);
             this.prefixNsList.add(namespace);
