@@ -22,6 +22,7 @@ import org.apache.commons.codec.binary.Base64OutputStream;
 import org.apache.xml.security.stax.securityToken.InboundSecurityToken;
 import org.apache.xml.security.stax.securityToken.SecurityTokenConstants;
 import org.apache.xml.security.stax.securityToken.SecurityTokenProvider;
+import org.apache.xml.security.utils.UnsyncByteArrayInputStream;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.xml.security.binding.xmldsig.KeyInfoType;
@@ -29,6 +30,7 @@ import org.apache.xml.security.binding.xmlenc.EncryptedDataType;
 import org.apache.xml.security.binding.xmlenc.EncryptedKeyType;
 import org.apache.xml.security.binding.xmlenc.ReferenceList;
 import org.apache.xml.security.binding.xmlenc.ReferenceType;
+import org.apache.xml.security.binding.xop.Include;
 import org.apache.xml.security.exceptions.XMLSecurityException;
 import org.apache.xml.security.stax.config.ConfigurationProperties;
 import org.apache.xml.security.stax.config.JCEAlgorithmMapper;
@@ -53,6 +55,8 @@ import javax.xml.stream.XMLStreamReader;
 import javax.xml.stream.events.Attribute;
 
 import java.io.*;
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.security.Key;
 import java.security.NoSuchAlgorithmException;
 import java.security.NoSuchProviderException;
@@ -61,12 +65,10 @@ import java.util.*;
 /**
  * Processor for decryption of EncryptedData XML structures
  *
- * @author $Author: coheigea $
- * @version $Revision: 1720201 $ $Date: 2015-12-15 18:13:17 +0100 (Tue, 15 Dec 2015) $
  */
 public abstract class AbstractDecryptInputProcessor extends AbstractInputProcessor {
 
-    private static final transient Logger log = LoggerFactory.getLogger(AbstractDecryptInputProcessor.class);
+    private static final transient Logger LOG = LoggerFactory.getLogger(AbstractDecryptInputProcessor.class);
 
     protected static final Integer maximumAllowedXMLStructureDepth =
             Integer.valueOf(ConfigurationProperties.getProperty("MaximumAllowedXMLStructureDepth"));
@@ -95,8 +97,9 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
         this.keyInfoType = keyInfoType;
 
         final List<JAXBElement<ReferenceType>> dataReferenceOrKeyReference = referenceList.getDataReferenceOrKeyReference();
-        references = new HashMap<String, ReferenceType>(dataReferenceOrKeyReference.size() + 1); //+1 because the HashMap will resize otherwise
-        processedReferences = new ArrayList<ReferenceType>(dataReferenceOrKeyReference.size());
+        final int dataReferenceOrKeyReferenceSize = dataReferenceOrKeyReference.size();
+        references = new HashMap<>((int) Math.ceil(dataReferenceOrKeyReferenceSize / 0.75));
+        processedReferences = new ArrayList<>(dataReferenceOrKeyReferenceSize);
 
         Iterator<JAXBElement<ReferenceType>> referenceTypeIterator = dataReferenceOrKeyReference.iterator();
         while (referenceTypeIterator.hasNext()) {
@@ -189,7 +192,7 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                 }
                 tmpXmlEventList.clear();
 
-                //the following logic reads the encryptedData structure and doesn't pass them further
+                //the following LOGic reads the encryptedData structure and doesn't pass them further
                 //through the chain
                 InputProcessorChain subInputProcessorChain = inputProcessorChain.createSubChain(this);
 
@@ -215,15 +218,6 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                         : subInputProcessorChain.processEvent();
                 }
 
-                //create a new Thread for streaming decryption
-                DecryptionThread decryptionThread =
-                        new DecryptionThread(subInputProcessorChain, isSecurityHeaderEvent);
-                Key decryptionKey =
-                    inboundSecurityToken.getSecretKey(algorithmURI, XMLSecurityConstants.Enc, encryptedDataType.getId());
-                decryptionKey = XMLSecurityUtils.prepareSecretKey(algorithmURI, decryptionKey.getEncoded());
-                decryptionThread.setSecretKey(decryptionKey);
-                decryptionThread.setSymmetricCipher(symCipher);
-                decryptionThread.setIvLength(ivLength);
                 XMLSecStartElement parentXMLSecStartElement = xmlSecStartElement.getParentXMLSecStartElement();
                 if (encryptedHeader) {
                     parentXMLSecStartElement = parentXMLSecStartElement.getParentXMLSecStartElement();
@@ -249,19 +243,64 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                             inboundSecurityToken, encryptedDataType);
                 }
 
-                Thread thread = new Thread(decryptionThread);
-                thread.setPriority(Thread.NORM_PRIORITY + 1);
-                thread.setName("decryption thread");
-                //when an exception in the decryption thread occurs, we want to forward them:
-                thread.setUncaughtExceptionHandler(decryptedEventReaderInputProcessor);
+                // Process the next event - we need to do this in case it's an xop:Include tag as we handle this
+                // differently compared to the usual inlined bytes. Note this only works if we have a single xop:Include
+                // chile element
+                XMLSecEvent nextEvent = null;
+                subInputProcessorChain.reset();
+                if (isSecurityHeaderEvent) {
+                    nextEvent = subInputProcessorChain.processHeaderEvent();
+                } else {
+                    nextEvent = subInputProcessorChain.processEvent();
+                }
 
-                decryptedEventReaderInputProcessor.setDecryptionThread(thread);
+                InputStream decryptInputStream = null;
+                if (nextEvent.isStartElement() && nextEvent.asStartElement().getName().equals(XMLSecurityConstants.TAG_XOP_INCLUDE)) {
+                    try {
+                        // Unmarshal the XOP Include Element
+                        Deque<XMLSecEvent> xmlSecEvents = new ArrayDeque<XMLSecEvent>();
+                        xmlSecEvents.push(nextEvent);
+                        xmlSecEvents.push(XMLSecEventFactory.createXmlSecEndElement(XMLSecurityConstants.TAG_XOP_INCLUDE));
 
-                //we have to start the thread before we call decryptionThread.getPipedInputStream().
-                //Otherwise we will end in a deadlock, because the StAX reader expects already data.
-                //@See some lines below:
-                log.debug("Starting decryption thread");
-                thread.start();
+                        Unmarshaller unmarshaller =
+                                XMLSecurityConstants.getJaxbUnmarshaller(getSecurityProperties().isDisableSchemaValidation());
+                        @SuppressWarnings("unchecked")
+                        JAXBElement<Include> includeJAXBElement =
+                                (JAXBElement<Include>) unmarshaller.unmarshal(new XMLSecurityEventReader(xmlSecEvents, 0));
+                        Include include = includeJAXBElement.getValue();
+                        String href = include.getHref();
+
+                        decryptInputStream =
+                            handleXOPInclude(inputProcessorChain, encryptedDataType, href, symCipher, inboundSecurityToken);
+                    } catch (JAXBException e) {
+                        throw new XMLSecurityException(e);
+                    }
+                } else {
+                    //create a new Thread for streaming decryption
+                    DecryptionThread decryptionThread = new DecryptionThread(subInputProcessorChain, isSecurityHeaderEvent, nextEvent);
+                    Key decryptionKey =
+                        inboundSecurityToken.getSecretKey(algorithmURI, XMLSecurityConstants.Enc, encryptedDataType.getId());
+                    decryptionKey = XMLSecurityUtils.prepareSecretKey(algorithmURI, decryptionKey.getEncoded());
+                    decryptionThread.setSecretKey(decryptionKey);
+                    decryptionThread.setSymmetricCipher(symCipher);
+                    decryptionThread.setIvLength(ivLength);
+
+                    Thread thread = new Thread(decryptionThread);
+                    thread.setPriority(Thread.NORM_PRIORITY + 1);
+                    thread.setName("decryption thread");
+                    //when an exception in the decryption thread occurs, we want to forward them:
+                    thread.setUncaughtExceptionHandler(decryptedEventReaderInputProcessor);
+
+                    decryptedEventReaderInputProcessor.setDecryptionThread(thread);
+
+                    //we have to start the thread before we call decryptionThread.getPipedInputStream().
+                    //Otherwise we will end in a deadlock, because the StAX reader expects already data.
+                    //@See some lines below:
+                    LOG.debug("Starting decryption thread");
+                    thread.start();
+
+                    decryptInputStream = decryptionThread.getPipedInputStream();
+                }
 
                 InputStream prologInputStream;
                 InputStream epilogInputStream;
@@ -274,7 +313,6 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                     throw new XMLSecurityException(e);
                 }
 
-                InputStream decryptInputStream = decryptionThread.getPipedInputStream();
                 decryptInputStream = applyTransforms(referenceType, decryptInputStream);
 
                 //spec says (4.2): "The cleartext octet sequence obtained in step 3 is
@@ -282,7 +320,7 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                 XMLStreamReader xmlStreamReader =
                         inputProcessorChain.getSecurityContext().<XMLInputFactory>get(
                                 XMLSecurityConstants.XMLINPUTFACTORY).createXMLStreamReader(
-                                new MultiInputStream(prologInputStream, decryptInputStream, epilogInputStream), "UTF-8");
+                                new MultiInputStream(prologInputStream, decryptInputStream, epilogInputStream), StandardCharsets.UTF_8.name());
 
                 //forward to wrapper element
                 forwardToWrapperElement(xmlStreamReader);
@@ -320,8 +358,8 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
         stringBuilder.append('\"');
 
         //apply all namespaces from current scope to get a valid documentfragment:
-        List<XMLSecNamespace> comparableNamespacesToApply = new ArrayList<XMLSecNamespace>();
-        List<XMLSecNamespace> comparableNamespaceList = new ArrayList<XMLSecNamespace>();
+        List<XMLSecNamespace> comparableNamespacesToApply = new ArrayList<>();
+        List<XMLSecNamespace> comparableNamespaceList = new ArrayList<>();
         xmlSecStartElement.getNamespacesFromCurrentScope(comparableNamespaceList);
         //reverse iteration -> From current element namespaces to parent namespaces
         for (int i = comparableNamespaceList.size() - 1; i >= 0; i--) {
@@ -347,7 +385,7 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
         }
 
         stringBuilder.append('>');
-        return new UnsynchronizedByteArrayInputStream(stringBuilder.toString().getBytes("UTF-8"));
+        return new UnsyncByteArrayInputStream(stringBuilder.toString().getBytes(StandardCharsets.UTF_8));
     }
 
     private InputStream writeWrapperEndElement() throws IOException {
@@ -358,7 +396,7 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
         stringBuilder.append(':');
         stringBuilder.append(wrapperElementName.getLocalPart());
         stringBuilder.append('>');
-        return new UnsynchronizedByteArrayInputStream(stringBuilder.toString().getBytes("UTF-8"));
+        return new UnsyncByteArrayInputStream(stringBuilder.toString().getBytes(StandardCharsets.UTF_8));
     }
 
     private void forwardToWrapperElement(XMLStreamReader xmlStreamReader) throws XMLStreamException {
@@ -522,6 +560,10 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                                                   EncryptedDataType encryptedDataType, Cipher cipher,
                                                   InboundSecurityToken inboundSecurityToken) throws XMLSecurityException;
 
+    protected abstract InputStream handleXOPInclude(InputProcessorChain inputProcessorChain,
+                                                  EncryptedDataType encryptedDataType, String href, Cipher cipher,
+                                                  InboundSecurityToken inboundSecurityToken) throws XMLSecurityException;
+
     protected ReferenceType matchesReferenceId(XMLSecStartElement xmlSecStartElement) {
         Attribute refId = getReferenceIDAttribute(xmlSecStartElement);
         if (refId != null) {
@@ -554,7 +596,7 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
     public abstract class AbstractDecryptedEventReaderInputProcessor
             extends AbstractInputProcessor implements Thread.UncaughtExceptionHandler {
 
-        private int currentXMLStructureDepth = 0;
+        private int currentXMLStructureDepth;
         private XMLStreamReader xmlStreamReader;
         private XMLSecStartElement parentXmlSecStartElement;
         private boolean encryptedHeader = false;
@@ -667,14 +709,16 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                             xmlSecEvent = inputProcessorChain.processEvent();
                         }
 
-                        //wait until the decryption thread dies...
-                        try {
-                            decryptionThread.join();
-                        } catch (InterruptedException e) {
-                            throw new XMLStreamException(e);
+                        if (decryptionThread != null) {
+                            //wait until the decryption thread dies...
+                            try {
+                                decryptionThread.join();
+                            } catch (InterruptedException e) {
+                                throw new XMLStreamException(e);
+                            }
+                            //...and test again for an exception in the decryption thread.
+                            testAndThrowUncaughtException();
                         }
-                        //...and test again for an exception in the decryption thread.
-                        testAndThrowUncaughtException();
                         inputProcessorChain.removeProcessor(this);
                     }
                     break;
@@ -718,12 +762,15 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
         private Cipher symmetricCipher;
         private int ivLength;
         private Key secretKey;
+        private final XMLSecEvent firstEvent;
 
         protected DecryptionThread(InputProcessorChain inputProcessorChain,
-                                   boolean header) throws XMLStreamException, XMLSecurityException {
+                                   boolean header,
+                                   XMLSecEvent firstEvent) throws XMLStreamException, XMLSecurityException {
 
             this.inputProcessorChain = inputProcessorChain;
             this.header = header;
+            this.firstEvent = firstEvent;
 
             //prepare the piped streams and connect them:
             this.pipedInputStream = new PipedInputStream(8192 * 5);
@@ -788,14 +835,14 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                 OutputStream base64OutputStream = new Base64OutputStream(replaceableOuputStream, false);
                 ivSplittingOutputStream.setParentOutputStream(replaceableOuputStream);
                 OutputStreamWriter outputStreamWriter =
-                        new OutputStreamWriter(base64OutputStream, inputProcessorChain.getDocumentContext().getEncoding());
+                        new OutputStreamWriter(base64OutputStream,
+                                               Charset.forName(inputProcessorChain.getDocumentContext().getEncoding()));
 
                 //read the encrypted data from the stream until an end-element occurs and write then
                 //to the decrypter-stream
+                XMLSecEvent xmlSecEvent = firstEvent;
                 exitLoop:
-                while (true) {
-                    XMLSecEvent xmlSecEvent = processNextEvent();
-
+                do {
                     switch (xmlSecEvent.getEventType()) {
                         case XMLStreamConstants.END_ELEMENT:
                             //this must be the CipherValue EndElement.
@@ -810,11 +857,13 @@ public abstract class AbstractDecryptInputProcessor extends AbstractInputProcess
                                     new Object[] {XMLSecurityUtils.getXMLEventAsString(xmlSecEvent)}
                             );
                     }
-                }
+
+                    xmlSecEvent = processNextEvent();
+                } while (true);
 
                 //close to get Cipher.doFinal() called
                 outputStreamWriter.close();
-                log.debug("Decryption thread finished");
+                LOG.debug("Decryption thread finished");
 
             } catch (Exception e) {
                 try {
