@@ -26,6 +26,9 @@ import org.apache.xml.security.exceptions.XMLSecurityException;
 import org.apache.xml.security.stax.ext.*;
 import org.apache.xml.security.stax.impl.transformer.canonicalizer.Canonicalizer20010315_Excl;
 import org.apache.xml.security.stax.securityToken.InboundSecurityToken;
+import org.apache.xml.security.utils.UnsyncBufferedOutputStream;
+import org.apache.xml.security.utils.UnsyncByteArrayInputStream;
+import org.apache.xml.security.utils.UnsyncByteArrayOutputStream;
 import org.apache.xml.security.stax.ext.stax.XMLSecEvent;
 import org.apache.xml.security.stax.ext.stax.XMLSecEventFactory;
 import org.apache.xml.security.stax.impl.algorithms.SignatureAlgorithm;
@@ -38,6 +41,7 @@ import javax.xml.stream.XMLStreamConstants;
 import javax.xml.stream.XMLStreamException;
 import javax.xml.stream.XMLStreamReader;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.OutputStream;
 import java.security.Key;
 import java.security.NoSuchAlgorithmException;
@@ -45,8 +49,6 @@ import java.security.NoSuchProviderException;
 import java.util.*;
 
 /**
- * @author $Author: coheigea $
- * @version $Revision: 1757635 $ $Date: 2016-08-25 11:13:42 +0200 (Thu, 25 Aug 2016) $
  */
 public abstract class AbstractSignatureInputHandler extends AbstractInputSecurityHeaderHandler {
 
@@ -146,23 +148,22 @@ public abstract class AbstractSignatureInputHandler extends AbstractInputSecurit
 
         Deque<XMLSecEvent> signedInfoDeque = new ArrayDeque<XMLSecEvent>();
 
-        UnsynchronizedByteArrayOutputStream unsynchronizedByteArrayOutputStream = new UnsynchronizedByteArrayOutputStream();
-        Transformer transformer = XMLSecurityUtils.getTransformer(
-                null,
-                unsynchronizedByteArrayOutputStream,
-                null,
-                signatureType.getSignedInfo().getCanonicalizationMethod().getAlgorithm(),
-                XMLSecurityConstants.DIRECTION.IN);
+        try (UnsyncByteArrayOutputStream unsynchronizedByteArrayOutputStream = new UnsyncByteArrayOutputStream()) {
+            Transformer transformer = XMLSecurityUtils.getTransformer(
+                    null,
+                    unsynchronizedByteArrayOutputStream,
+                    null,
+                    signatureType.getSignedInfo().getCanonicalizationMethod().getAlgorithm(),
+                    XMLSecurityConstants.DIRECTION.IN);
 
-        Iterator<XMLSecEvent> iterator = eventDeque.descendingIterator();
-        //forward to <Signature> Element
-        int i = 0;
-        while (i < index) {
-            iterator.next();
-            i++;
-        }
+            Iterator<XMLSecEvent> iterator = eventDeque.descendingIterator();
+            //forward to <Signature> Element
+            int i = 0;
+            while (i < index) {
+                iterator.next();
+                i++;
+            }
 
-        try {
             loop:
             while (iterator.hasNext()) {
                 XMLSecEvent xmlSecEvent = iterator.next();
@@ -191,24 +192,25 @@ public abstract class AbstractSignatureInputHandler extends AbstractInputSecurit
 
             transformer.doFinal();
 
-            XMLStreamReader xmlStreamReader = inputProcessorChain.getSecurityContext().
-                    <XMLInputFactory>get(XMLSecurityConstants.XMLINPUTFACTORY).
-                    createXMLStreamReader(new UnsynchronizedByteArrayInputStream(unsynchronizedByteArrayOutputStream.toByteArray()));
+            try (InputStream is = new UnsyncByteArrayInputStream(unsynchronizedByteArrayOutputStream.toByteArray())) {
+                XMLStreamReader xmlStreamReader = inputProcessorChain.getSecurityContext().
+                        <XMLInputFactory>get(XMLSecurityConstants.XMLINPUTFACTORY).
+                        createXMLStreamReader(is);
 
-            while (xmlStreamReader.hasNext()) {
-                XMLSecEvent xmlSecEvent = XMLSecEventFactory.allocate(xmlStreamReader, null);
-                signedInfoDeque.push(xmlSecEvent);
-                xmlStreamReader.next();
+                while (xmlStreamReader.hasNext()) {
+                    XMLSecEvent xmlSecEvent = XMLSecEventFactory.allocate(xmlStreamReader, null);
+                    signedInfoDeque.push(xmlSecEvent);
+                    xmlStreamReader.next();
+                }
+
+                @SuppressWarnings("unchecked")
+                final SignedInfoType signedInfoType =
+                        ((JAXBElement<SignedInfoType>) parseStructure(signedInfoDeque, 0, securityProperties)).getValue();
+                signatureType.setSignedInfo(signedInfoType);
+
+                return signedInfoDeque;
             }
-
-            @SuppressWarnings("unchecked")
-            final SignedInfoType signedInfoType =
-                    ((JAXBElement<SignedInfoType>) parseStructure(signedInfoDeque, 0, securityProperties)).getValue();
-            signatureType.setSignedInfo(signedInfoType);
-
-            return signedInfoDeque;
-
-        } catch (XMLStreamException e) {
+        } catch (XMLStreamException | IOException e) {
             throw new XMLSecurityException(e);
         }
     }
@@ -305,7 +307,7 @@ public abstract class AbstractSignatureInputHandler extends AbstractInputSecurit
                                 algorithmURI);
                 signatureAlgorithm.engineInitVerify(verifyKey);
                 signerOutputStream = new SignerOutputStream(signatureAlgorithm);
-                bufferedSignerOutputStream = new UnsynchronizedBufferedOutputStream(signerOutputStream);
+                bufferedSignerOutputStream = new UnsyncBufferedOutputStream(signerOutputStream);
 
                 final CanonicalizationMethodType canonicalizationMethodType =
                         signatureType.getSignedInfo().getCanonicalizationMethod();
@@ -317,7 +319,7 @@ public abstract class AbstractSignatureInputHandler extends AbstractInputSecurit
 
                 Map<String, Object> transformerProperties = null;
                 if (inclusiveNamespacesType != null) {
-                    transformerProperties = new HashMap<String, Object>();
+                    transformerProperties = new HashMap<>();
                     transformerProperties.put(
                             Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST,
                             inclusiveNamespacesType.getPrefixList());
