@@ -18,9 +18,9 @@
  */
 package org.apache.xml.security.stax.impl.processor.output;
 
-import org.apache.commons.codec.binary.Base64;
 import org.apache.xml.security.stax.securityToken.SecurityTokenConstants;
 import org.apache.xml.security.stax.securityToken.SecurityTokenProvider;
+import org.apache.xml.security.utils.XMLUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.xml.security.exceptions.XMLSecurityException;
@@ -51,12 +51,10 @@ import java.util.List;
 /**
  * Processor to encrypt XML structures
  *
- * @author $Author: coheigea $
- * @version $Revision: 1236690 $ $Date: 2012-01-27 14:07:10 +0000 (Fri, 27 Jan 2012) $
  */
 public class XMLEncryptOutputProcessor extends AbstractEncryptOutputProcessor {
 
-    private static final transient Logger log = LoggerFactory.getLogger(XMLEncryptOutputProcessor.class);
+    private static final transient Logger LOG = LoggerFactory.getLogger(XMLEncryptOutputProcessor.class);
 
     public XMLEncryptOutputProcessor() throws XMLSecurityException {
         super();
@@ -71,7 +69,7 @@ public class XMLEncryptOutputProcessor extends AbstractEncryptOutputProcessor {
             if (getActiveInternalEncryptionOutputProcessor() == null) {
                 SecurePart securePart = securePartMatches(xmlSecStartElement, outputProcessorChain, XMLSecurityConstants.ENCRYPTION_PARTS);
                 if (securePart != null) {
-                    log.debug("Matched encryptionPart for encryption");
+                    LOG.debug("Matched encryptionPart for encryption");
                     String tokenId = outputProcessorChain.getSecurityContext().get(
                             XMLSecurityConstants.PROP_USE_THIS_TOKEN_ID_FOR_ENCRYPTION);
                     SecurityTokenProvider<OutboundSecurityToken> securityTokenProvider =
@@ -139,12 +137,12 @@ public class XMLEncryptOutputProcessor extends AbstractEncryptOutputProcessor {
 
                         createStartElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_dsig_KeyInfo, true, null);
 
-                        List<XMLSecAttribute> attributes = new ArrayList<XMLSecAttribute>(1);
+                        List<XMLSecAttribute> attributes = new ArrayList<>(1);
                         String keyId = IDGenerator.generateID("EK");
                         attributes.add(createAttribute(XMLSecurityConstants.ATT_NULL_Id, keyId));
                         createStartElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_xenc_EncryptedKey, true, attributes);
 
-                        attributes = new ArrayList<XMLSecAttribute>(1);
+                        attributes = new ArrayList<>(1);
                         attributes.add(createAttribute(XMLSecurityConstants.ATT_NULL_Algorithm, encryptionKeyTransportAlgorithm));
                         createStartElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_xenc_EncryptionMethod, false, attributes);
 
@@ -157,19 +155,19 @@ public class XMLEncryptOutputProcessor extends AbstractEncryptOutputProcessor {
                             byte[] oaepParams = getSecurityProperties().getEncryptionKeyTransportOAEPParams();
                             if (oaepParams != null) {
                                 createStartElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_xenc_OAEPparams, false, null);
-                                createCharactersAndOutputAsEvent(outputProcessorChain, Base64.encodeBase64String(oaepParams));
+                                createCharactersAndOutputAsEvent(outputProcessorChain, XMLUtils.encodeToString(oaepParams));
                                 createEndElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_xenc_OAEPparams);
                             }
 
                             if (encryptionKeyTransportDigestAlgorithm != null) {
-                                attributes = new ArrayList<XMLSecAttribute>(1);
+                                attributes = new ArrayList<>(1);
                                 attributes.add(createAttribute(XMLSecurityConstants.ATT_NULL_Algorithm, encryptionKeyTransportDigestAlgorithm));
                                 createStartElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_dsig_DigestMethod, true, attributes);
                                 createEndElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_dsig_DigestMethod);
                             }
 
                             if (encryptionKeyTransportMGFAlgorithm != null) {
-                                attributes = new ArrayList<XMLSecAttribute>(1);
+                                attributes = new ArrayList<>(1);
                                 attributes.add(createAttribute(XMLSecurityConstants.ATT_NULL_Algorithm, encryptionKeyTransportMGFAlgorithm));
                                 createStartElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_xenc11_MGF, true, attributes);
                                 createEndElementAndOutputAsEvent(outputProcessorChain, XMLSecurityConstants.TAG_xenc11_MGF);
@@ -240,7 +238,7 @@ public class XMLEncryptOutputProcessor extends AbstractEncryptOutputProcessor {
                             }
                             byte[] encryptedEphemeralKey = cipher.wrap(sessionKey);
 
-                            createCharactersAndOutputAsEvent(outputProcessorChain, new Base64(76, new byte[]{'\n'}).encodeToString(encryptedEphemeralKey));
+                            createCharactersAndOutputAsEvent(outputProcessorChain, XMLUtils.encodeToString(encryptedEphemeralKey));
 
                         } catch (NoSuchPaddingException e) {
                             throw new XMLSecurityException(e);
