@@ -26,8 +26,8 @@ import org.apache.xml.security.stax.ext.XMLSecurityUtils;
 import org.apache.xml.security.stax.ext.stax.*;
 import org.apache.xml.security.stax.impl.processor.input.XMLEventReaderInputProcessor;
 import org.apache.xml.security.stax.impl.transformer.TransformIdentity;
-import org.apache.xml.security.stax.impl.util.UnsynchronizedByteArrayInputStream;
-import org.apache.xml.security.stax.impl.util.UnsynchronizedByteArrayOutputStream;
+import org.apache.xml.security.utils.UnsyncByteArrayInputStream;
+import org.apache.xml.security.utils.UnsyncByteArrayOutputStream;
 
 import javax.xml.namespace.QName;
 import javax.xml.stream.*;
@@ -35,8 +35,6 @@ import java.io.*;
 import java.util.*;
 
 /**
- * @author $Author: coheigea $
- * @version $Revision: 1720201 $ $Date: 2015-12-15 18:13:17 +0100 (Tue, 15 Dec 2015) $
  */
 public abstract class CanonicalizerBase extends TransformIdentity {
 
@@ -65,7 +63,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
         NODE_AFTER_DOCUMENT_ELEMENT
     }
 
-    private static final Map<String, byte[]> cache = new WeakHashMap<String, byte[]>();
+    private static final Map<String, byte[]> CACHE = Collections.synchronizedMap(new WeakHashMap<String, byte[]>());
     private final C14NStack<XMLSecEvent> outputStack = new C14NStack<XMLSecEvent>();
     private boolean includeComments = false;
     private DocumentLevel currentDocumentLevel = DocumentLevel.NODE_BEFORE_DOCUMENT_ELEMENT;
@@ -84,7 +82,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
     @Override
     public void setTransformer(Transformer transformer) throws XMLSecurityException {
         //we support only transformers which takes an InputStream otherwise we will break the C14N
-        setOutputStream(new UnsynchronizedByteArrayOutputStream());
+        setOutputStream(new UnsyncByteArrayOutputStream());
         super.setTransformer(transformer);
     }
 
@@ -99,7 +97,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
         if (found == null || found.getNamespaceURI() == null
                 || !found.getNamespaceURI().equals(elementNamespace.getNamespaceURI())) {
 
-            utilizedNamespaces = new ArrayList<XMLSecNamespace>(2);
+            utilizedNamespaces = new ArrayList<>(2);
             utilizedNamespaces.add(elementNamespace);
             outputStack.peek().add(elementNamespace);
         }
@@ -115,7 +113,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
             }
 
             if (utilizedNamespaces == Collections.<XMLSecNamespace>emptyList()) {
-                utilizedNamespaces = new ArrayList<XMLSecNamespace>(2);
+                utilizedNamespaces = new ArrayList<>(2);
             }
             utilizedNamespaces.add(comparableNamespace);
             outputStack.peek().add(comparableNamespace);
@@ -137,7 +135,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                     || !resultNamespace.getNamespaceURI().equals(attributeNamespace.getNamespaceURI())) {
 
                 if (utilizedNamespaces == Collections.<XMLSecNamespace>emptyList()) {
-                    utilizedNamespaces = new ArrayList<XMLSecNamespace>(2);
+                    utilizedNamespaces = new ArrayList<>(2);
                 }
                 utilizedNamespaces.add(attributeNamespace);
                 outputStack.peek().add(attributeNamespace);
@@ -154,14 +152,14 @@ public abstract class CanonicalizerBase extends TransformIdentity {
             return Collections.emptyList();
         }
 
-        return new ArrayList<XMLSecAttribute>(comparableAttributes);
+        return new ArrayList<>(comparableAttributes);
     }
 
     protected List<XMLSecNamespace> getInitialUtilizedNamespaces(final XMLSecStartElement xmlSecStartElement,
                                                                       final C14NStack<XMLSecEvent> outputStack) {
 
-        final List<XMLSecNamespace> utilizedNamespaces = new ArrayList<XMLSecNamespace>();
-        List<XMLSecNamespace> visibleNamespaces = new ArrayList<XMLSecNamespace>();
+        final List<XMLSecNamespace> utilizedNamespaces = new ArrayList<>();
+        List<XMLSecNamespace> visibleNamespaces = new ArrayList<>();
         xmlSecStartElement.getNamespacesFromCurrentScope(visibleNamespaces);
         for (int i = 0; i < visibleNamespaces.size(); i++) {
             XMLSecNamespace comparableNamespace = visibleNamespaces.get(i);
@@ -190,7 +188,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
 
         List<XMLSecAttribute> utilizedAttributes = Collections.emptyList();
 
-        List<XMLSecAttribute> comparableAttributes = new ArrayList<XMLSecAttribute>();
+        List<XMLSecAttribute> comparableAttributes = new ArrayList<>();
         xmlSecStartElement.getAttributesFromCurrentScope(comparableAttributes);
         for (int i = 0; i < comparableAttributes.size(); i++) {
             XMLSecAttribute comparableAttribute = comparableAttributes.get(i);
@@ -201,7 +199,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                 continue;
             }
             if (utilizedAttributes == Collections.<XMLSecAttribute>emptyList()) {
-                utilizedAttributes = new ArrayList<XMLSecAttribute>(2);
+                utilizedAttributes = new ArrayList<>(2);
             }
             utilizedAttributes.add(comparableAttribute);
             outputStack.peek().add(comparableAttribute);
@@ -217,7 +215,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                 continue;
             }
             if (utilizedAttributes == Collections.<XMLSecAttribute>emptyList()) {
-                utilizedAttributes = new ArrayList<XMLSecAttribute>(2);
+                utilizedAttributes = new ArrayList<>(2);
             }
             utilizedAttributes.add(comparableAttribute);
         }
@@ -253,8 +251,8 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                     final List<XMLSecAttribute> utilizedAttributes;
 
                     if (firstCall) {
-                        utilizedNamespaces = new ArrayList<XMLSecNamespace>();
-                        utilizedAttributes = new ArrayList<XMLSecAttribute>();
+                        utilizedNamespaces = new ArrayList<>();
+                        utilizedAttributes = new ArrayList<>();
                         outputStack.peek().add(XMLSecEventFactory.createXMLSecNamespace(null, ""));
                         outputStack.push(Collections.<Comparable>emptyList());
 
@@ -270,11 +268,11 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                     outputStream.write('<');
                     final String prefix = xmlSecStartElement.getName().getPrefix();
                     if (prefix != null && !prefix.isEmpty()) {
-                        UtfHelpper.writeByte(prefix, outputStream, cache);
+                        UtfHelpper.writeByte(prefix, outputStream, CACHE);
                         outputStream.write(DOUBLEPOINT);
                     }
                     final String name = xmlSecStartElement.getName().getLocalPart();
-                    UtfHelpper.writeByte(name, outputStream, cache);
+                    UtfHelpper.writeByte(name, outputStream, CACHE);
 
                     if (!utilizedNamespaces.isEmpty()) {
                         Collections.sort(utilizedNamespaces);
@@ -285,9 +283,9 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                             }
 
                             if (xmlSecNamespace.isDefaultNamespaceDeclaration()) {
-                                outputAttrToWriter(null, XMLNS, xmlSecNamespace.getNamespaceURI(), outputStream, cache);
+                                outputAttrToWriter(null, XMLNS, xmlSecNamespace.getNamespaceURI(), outputStream, CACHE);
                             } else {
-                                outputAttrToWriter(XMLNS, xmlSecNamespace.getPrefix(), xmlSecNamespace.getNamespaceURI(), outputStream, cache);
+                                outputAttrToWriter(XMLNS, xmlSecNamespace.getPrefix(), xmlSecNamespace.getNamespaceURI(), outputStream, CACHE);
                             }
                         }
                     }
@@ -300,9 +298,9 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                             final QName attributeName = xmlSecAttribute.getName();
                             final String attributeNamePrefix = attributeName.getPrefix();
                             if (attributeNamePrefix != null && !attributeNamePrefix.isEmpty()) {
-                                outputAttrToWriter(attributeNamePrefix, attributeName.getLocalPart(), xmlSecAttribute.getValue(), outputStream, cache);
+                                outputAttrToWriter(attributeNamePrefix, attributeName.getLocalPart(), xmlSecAttribute.getValue(), outputStream, CACHE);
                             } else {
-                                outputAttrToWriter(null, attributeName.getLocalPart(), xmlSecAttribute.getValue(), outputStream, cache);
+                                outputAttrToWriter(null, attributeName.getLocalPart(), xmlSecAttribute.getValue(), outputStream, CACHE);
                             }
                         }
                     }
@@ -314,10 +312,10 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                     final String localPrefix = xmlSecEndElement.getName().getPrefix();
                     outputStream.write(_END_TAG);
                     if (localPrefix != null && !localPrefix.isEmpty()) {
-                        UtfHelpper.writeByte(localPrefix, outputStream, cache);
+                        UtfHelpper.writeByte(localPrefix, outputStream, CACHE);
                         outputStream.write(DOUBLEPOINT);
                     }
-                    UtfHelpper.writeByte(xmlSecEndElement.getName().getLocalPart(), outputStream, cache);
+                    UtfHelpper.writeByte(xmlSecEndElement.getName().getLocalPart(), outputStream, CACHE);
                     outputStream.write('>');
 
                     //We finished with this level, pop to the previous definitions.
@@ -328,7 +326,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
 
                     break;
                 case XMLStreamConstants.PROCESSING_INSTRUCTION:
-                    outputPItoWriter(((XMLSecProcessingInstruction) xmlSecEvent), outputStream, currentDocumentLevel);
+                    outputPItoWriter((XMLSecProcessingInstruction) xmlSecEvent, outputStream, currentDocumentLevel);
                     break;
                 case XMLStreamConstants.CHARACTERS:
                     if (currentDocumentLevel == DocumentLevel.NODE_NOT_BEFORE_OR_AFTER_DOCUMENT_ELEMENT) {
@@ -337,7 +335,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
                     break;
                 case XMLStreamConstants.COMMENT:
                     if (includeComments) {
-                        outputCommentToWriter(((XMLSecComment) xmlSecEvent), outputStream, currentDocumentLevel);
+                        outputCommentToWriter((XMLSecComment) xmlSecEvent, outputStream, currentDocumentLevel);
                     }
                     break;
                 case XMLStreamConstants.SPACE:
@@ -390,20 +388,24 @@ public abstract class CanonicalizerBase extends TransformIdentity {
     @Override
     public void doFinal() throws XMLStreamException {
         if (getTransformer() != null) {
-            UnsynchronizedByteArrayOutputStream baos = (UnsynchronizedByteArrayOutputStream)getOutputStream();
-            getTransformer().transform(new UnsynchronizedByteArrayInputStream(baos.toByteArray()));
-            getTransformer().doFinal();
+            UnsyncByteArrayOutputStream baos = (UnsyncByteArrayOutputStream)getOutputStream();
+            try (InputStream is = new UnsyncByteArrayInputStream(baos.toByteArray())) {
+                getTransformer().transform(is);
+                getTransformer().doFinal();
+            } catch (IOException ex) {
+                throw new XMLStreamException(ex);
+            }
         }
     }
 
     protected static void outputAttrToWriter(final String prefix, final String name, final String value, final OutputStream writer,
-                                             final Map<String, byte[]> cache) throws IOException {
+                                             final Map<String, byte[]> CACHE) throws IOException {
         writer.write(' ');
         if (prefix != null) {
-            UtfHelpper.writeByte(prefix, writer, cache);
+            UtfHelpper.writeByte(prefix, writer, CACHE);
             UtfHelpper.writeCodePointToUtf8(DOUBLEPOINT, writer);
         }
-        UtfHelpper.writeByte(name, writer, cache);
+        UtfHelpper.writeByte(name, writer, CACHE);
         writer.write(EQUAL_STRING);
         byte[] toWrite;
         final int length = value.length();
@@ -659,7 +661,7 @@ public abstract class CanonicalizerBase extends TransformIdentity {
             List<Comparable> list = super.peekFirst();
             if (list == Collections.<Comparable>emptyList()) {
                 super.removeFirst();
-                list = new ArrayList<Comparable>();
+                list = new ArrayList<>();
                 super.addFirst(list);
             }
             return list;
