@@ -18,23 +18,23 @@
  */
 package org.apache.xml.security.utils;
 
+import java.io.IOException;
 import java.io.OutputStream;
 
 /**
  * A simple Unsynced ByteArrayOutputStream
- * @author raul
  *
  */
-public class UnsyncByteArrayOutputStream extends OutputStream  {	
+public class UnsyncByteArrayOutputStream extends OutputStream  {
 
-    // Maximum array size. Using same value as ArrayList in OpenJDK. 
+    // Maximum array size. Using same value as ArrayList in OpenJDK.
     // Integer.MAX_VALUE doesn't work on some VMs, as some header values are reserved
     private static final int VM_ARRAY_INDEX_MAX_VALUE = Integer.MAX_VALUE - 8;
     private static final int INITIAL_SIZE = 8192;
 
     private byte[] buf;
     private int size = INITIAL_SIZE;
-    private int pos = 0;
+    private int pos;
 
     public UnsyncByteArrayOutputStream() {
         buf = new byte[INITIAL_SIZE];
@@ -42,7 +42,7 @@ public class UnsyncByteArrayOutputStream extends OutputStream  {
 
     public void write(byte[] arg0) {
         if ((VM_ARRAY_INDEX_MAX_VALUE - pos) < arg0.length) {
-            throw new OutOfMemoryError();
+            throw new OutOfMemoryError("Required length exceeds implementation limit");
         }
         int newPos = pos + arg0.length;
         if (newPos > size) {
@@ -54,7 +54,7 @@ public class UnsyncByteArrayOutputStream extends OutputStream  {
 
     public void write(byte[] arg0, int arg1, int arg2) {
         if ((VM_ARRAY_INDEX_MAX_VALUE - pos) < arg2) {
-            throw new OutOfMemoryError();
+            throw new OutOfMemoryError("Required length exceeds implementation limit");
         }
         int newPos = pos + arg2;
         if (newPos > size) {
@@ -66,13 +66,13 @@ public class UnsyncByteArrayOutputStream extends OutputStream  {
 
     public void write(int arg0) {
         if (VM_ARRAY_INDEX_MAX_VALUE - pos == 0) {
-            throw new OutOfMemoryError();
+            throw new OutOfMemoryError("Required length exceeds implementation limit");
         }
         int newPos = pos + 1;
         if (newPos > size) {
             expandSize(newPos);
         }
-        buf[pos++] = (byte)arg0;		
+        buf[pos++] = (byte)arg0;
     }
 
     public byte[] toByteArray() {
@@ -84,7 +84,20 @@ public class UnsyncByteArrayOutputStream extends OutputStream  {
     public void reset() {
         pos = 0;
     }
-    
+
+    /**
+     * Takes the contents of this stream and writes it to the output stream
+     * {@code out}.
+     *
+     * @param out
+     *            an OutputStream on which to write the contents of this stream.
+     * @throws IOException
+     *             if an error occurs while writing to {@code out}.
+     */
+    public void writeTo(OutputStream out) throws IOException {
+        out.write(buf, 0, pos);
+    }
+
     private void expandSize(int newPos) {
         int newSize = size;
         while (newPos > newSize) {
@@ -99,4 +112,4 @@ public class UnsyncByteArrayOutputStream extends OutputStream  {
         buf = newBuf;
         size = newSize;
     }
-}
\ No newline at end of file
+}
