@@ -26,15 +26,14 @@ import org.apache.xml.security.signature.XMLSignatureInput;
 /**
  * During reference validation, we have to retrieve resources from somewhere.
  *
- * @author $Author: coheigea $
  */
 public abstract class ResourceResolverSpi {
 
-    private static org.slf4j.Logger log =
+    private static final org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(ResourceResolverSpi.class);
 
     /** Field properties */
-    protected Map<String, String> properties = null;
+    protected Map<String, String> properties;
 
     /**
      * This is the workhorse method used to resolve resources.
@@ -55,7 +54,7 @@ public abstract class ResourceResolverSpi {
      */
     public void engineSetProperty(String key, String value) {
         if (properties == null) {
-            properties = new HashMap<String, String>();
+            properties = new HashMap<>();
         }
         properties.put(key, value);
     }
@@ -80,7 +79,7 @@ public abstract class ResourceResolverSpi {
     public void engineAddProperies(Map<String, String> newProperties) {
         if (newProperties != null && !newProperties.isEmpty()) {
             if (properties == null) {
-                properties = new HashMap<String, String>();
+                properties = new HashMap<>();
             }
             properties.putAll(newProperties);
         }
@@ -89,7 +88,7 @@ public abstract class ResourceResolverSpi {
     /**
      * Tells if the implementation does can be reused by several threads safely.
      * It normally means that the implementation does not have any member, or there is
-     * member change between engineCanResolve & engineResolve invocations. Or it maintains all
+     * member change between engineCanResolve and engineResolve invocations. Or it maintains all
      * member info in ThreadLocal methods.
      */
     public boolean engineIsThreadSafe() {
@@ -158,8 +157,8 @@ public abstract class ResourceResolverSpi {
                 && ch1 == ':' && ch2 == '/'
                 && ch3 != '/';
 
-            if (isDosFilename && log.isDebugEnabled()) {
-                log.debug("Found DOS filename: " + str);
+            if (isDosFilename) {
+                LOG.debug("Found DOS filename: {}", str);
             }
         }
 
