@@ -21,6 +21,8 @@
  */
 package javax.xml.crypto.test;
 
+import static org.junit.Assert.*;
+
 import java.io.*;
 import java.util.*;
 import javax.xml.crypto.*;
@@ -28,19 +30,18 @@ import javax.xml.crypto.*;
 /**
  * Unit test for javax.xml.crypto.OctetStreamData
  *
- * @author Valerie Peng
  */
-public class OctetStreamDataTest extends org.junit.Assert {
+public class OctetStreamDataTest {
 
     @org.junit.Test
-    public void testConstructor() {
+    public void testConstructor() throws Exception {
         // test OctetStreamData(InputStream) and
         // OctetStreamData(InputStream, String, String)
         OctetStreamData osdata;
         try {
             osdata = new OctetStreamData(null);
             fail("Should raise a NPE for null input stream");
-        } catch (NullPointerException npe) {}	
+        } catch (NullPointerException npe) {}
         try {
             osdata = new OctetStreamData(null, "uri", "mimeType");
             fail("Should raise a NPE for null input stream");
@@ -49,8 +50,8 @@ public class OctetStreamDataTest extends org.junit.Assert {
         int len = 300;
         byte[] in = new byte[len];
         new Random().nextBytes(in);
-        ByteArrayInputStream bais = new ByteArrayInputStream(in);
-        try {
+
+        try (ByteArrayInputStream bais = new ByteArrayInputStream(in)) {
             osdata = new OctetStreamData(bais);
             assertNotNull(osdata);
             assertEquals(osdata.getOctetStream(), bais);
@@ -62,20 +63,14 @@ public class OctetStreamDataTest extends org.junit.Assert {
             assertEquals(osdata.getOctetStream(), bais);
             assertNull(osdata.getURI());
             assertNull(osdata.getMimeType());
-        } catch (Exception ex) {
-            fail("Unexpected Exception: " + ex);
-        }
 
-        String uri="testUri";
-        String mimeType="test";
-        try {
+            String uri="testUri";
+            String mimeType="test";
             osdata = new OctetStreamData(bais, uri, mimeType);
             assertNotNull(osdata);
             assertEquals(osdata.getOctetStream(), bais);
             assertEquals(osdata.getURI(), uri);
             assertEquals(osdata.getMimeType(), mimeType);
-        } catch (Exception ex) {
-            fail("Unexpected Exception: " + ex);
         }
     }
 }
