@@ -21,6 +21,8 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.assertTrue;
+
 import java.io.File;
 import java.security.Security;
 
@@ -30,9 +32,8 @@ import javax.xml.crypto.test.KeySelectors;
  * This is a testcase to validate all "merlin-exc-c14n-one"
  * testcases from Baltimore
  *
- * @author Sean Mullan
  */
-public class BaltimoreExcC14n1Test extends org.junit.Assert {
+public class BaltimoreExcC14n1Test {
 
     private SignatureValidator validator;
 
