@@ -34,9 +34,9 @@ import org.apache.jcp.xml.dsig.internal.dom.XMLDSigRI;
  * invokes the XMLSignature API. It tests that there are not provider class
  * loading issues with more than one classloader (see 6380953).
  */
-public class ClassLoaderTest extends org.junit.Assert {
+public class ClassLoaderTest {
 
-    private static org.slf4j.Logger log =
+    private static final org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(ClassLoaderTest.class);
 
     @SuppressWarnings("resource")
@@ -80,12 +80,8 @@ public class ClassLoaderTest extends org.junit.Assert {
             (urls, Thread.currentThread().getContextClassLoader());
         //load security provider using current class loader
         final Provider provider = new XMLDSigRI();
-        AccessController.doPrivileged(new java.security.PrivilegedAction<Object>() {
-            public Object run() {
-                Security.addProvider(provider);
-                return null;
-            }
-        });
+        AccessController.doPrivileged((java.security.PrivilegedAction<Object>)
+            () -> Security.addProvider(provider));
         // get the provider from java.security.Security using URLClassLoader.
         // Need to use introspection to invoke methods to avoid using the
         // current class loader
@@ -97,18 +93,16 @@ public class ClassLoaderTest extends org.junit.Assert {
             ("javax.xml.crypto.dsig.spec.C14NMethodParameterSpec");
         Method canonicalizationMethod = factoryClass.getDeclaredMethod
             ("newCanonicalizationMethod",
-                new Class[]{String.class,methodParameterClass});
+                new Class[]{String.class, methodParameterClass});
         Object factory = factoryMethod.invoke(null, "DOM");
         long start = System.currentTimeMillis();
         for (int i = 0; i < 100; i++) {
             canonicalizationMethod.invoke
-                (factory, new Object[]{CanonicalizationMethod.EXCLUSIVE,null});
+                (factory, new Object[]{CanonicalizationMethod.EXCLUSIVE, null});
         }
         long end = System.currentTimeMillis();
         long elapsed = end-start;
-        if (log.isDebugEnabled()) {
-            log.debug("Elapsed: " + elapsed);
-        }
+        LOG.debug("Elapsed: {}", elapsed);
     }
 
     @SuppressWarnings("resource")
