@@ -21,8 +21,11 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.*;
+
 import java.io.*;
 import java.math.BigInteger;
+import java.nio.charset.StandardCharsets;
 import java.security.Key;
 import java.security.KeyStore;
 import java.security.PublicKey;
@@ -44,7 +47,6 @@ import javax.xml.crypto.dsig.dom.DOMSignContext;
 import javax.xml.crypto.dsig.dom.DOMValidateContext;
 import javax.xml.crypto.dsig.keyinfo.*;
 import javax.xml.crypto.dsig.spec.*;
-import javax.xml.parsers.DocumentBuilder;
 import javax.xml.transform.*;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
@@ -58,13 +60,11 @@ import javax.xml.crypto.test.KeySelectors;
  * Test that recreates merlin-xmldsig-twenty-three test vectors but with
  * different keys and X.509 data.
  *
- * @author Sean Mullan
  */
-public class CreateBaltimore23Test extends org.junit.Assert {
+public class CreateBaltimore23Test {
 
     private XMLSignatureFactory fac;
     private KeyInfoFactory kifac;
-    private DocumentBuilder db;
     private CanonicalizationMethod withoutComments;
     private Transform withComments;
     private SignatureMethod dsaSha1, rsaSha1;
@@ -79,6 +79,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
     private final URIDereferencer ud;
 
     static {
+        System.setProperty("org.apache.xml.security.allowUnsafeResourceResolving", "true");
         Security.insertProviderAt
             (new org.apache.jcp.xml.dsig.internal.dom.XMLDSigRI(), 1);
     }
@@ -87,7 +88,6 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         fac = XMLSignatureFactory.getInstance
             ("DOM", new org.apache.jcp.xml.dsig.internal.dom.XMLDSigRI());
         kifac = fac.getKeyInfoFactory();
-        db = XMLUtils.createDocumentBuilder(false);
 
         // get key & self-signed certificate from keystore
         String fs = System.getProperty("file.separator");
@@ -114,7 +114,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         rsa = kifac.newKeyInfo(Collections.singletonList
             (kifac.newKeyValue(TestUtils.getPublicKey("RSA"))));
         rsaSha1 = fac.newSignatureMethod(SignatureMethod.RSA_SHA1, null);
-        sks = new KeySelectors.SecretKeySelector("secret".getBytes("ASCII"));
+        sks = new KeySelectors.SecretKeySelector("secret".getBytes(StandardCharsets.US_ASCII));
 
         ud = new LocalHttpCacheURIDereferencer();
     }
@@ -133,7 +133,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         // create XMLSignature
         XMLSignature sig = fac.newXMLSignature(si, dsa);
 
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         Element envelope = doc.createElementNS
             ("http://example.org/envelope", "Envelope");
         envelope.setAttributeNS
@@ -143,7 +143,6 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         DOMSignContext dsc = new DOMSignContext(signingKey, envelope);
 
         sig.sign(dsc);
-        TestUtils.validateSecurityOrEncryptionElement(envelope.getFirstChild());
 
         DOMValidateContext dvc = new DOMValidateContext
             (kvks, envelope.getFirstChild());
@@ -171,7 +170,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
             (SignatureMethod.HMAC_SHA1, new HMACParameterSpec(40));
         try {
             test_create_signature_enveloping(hmacSha1, null,
-                TestUtils.getSecretKey("secret".getBytes("ASCII")), sks, false);
+                TestUtils.getSecretKey("secret".getBytes(StandardCharsets.US_ASCII)), sks, false);
             fail("Expected HMACOutputLength Exception");
         } catch (XMLSignatureException xse) {
             System.out.println(xse.getMessage());
@@ -185,7 +184,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         SignatureMethod hmacSha1 = fac.newSignatureMethod
             (SignatureMethod.HMAC_SHA1, null);
         test_create_signature_enveloping(hmacSha1, null,
-            TestUtils.getSecretKey("secret".getBytes("ASCII")), sks, false);
+            TestUtils.getSecretKey("secret".getBytes(StandardCharsets.US_ASCII)), sks, false);
     }
 
     @org.junit.Test
@@ -232,7 +231,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
             return;
         }
 
-        List<Object> xds = new ArrayList<Object>();
+        List<Object> xds = new ArrayList<>();
         CertificateFactory cf = CertificateFactory.getInstance("X.509");
         xds.add(signingCert);
         String fs = System.getProperty("file.separator");
@@ -289,7 +288,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
     public void test_create_signature_x509_ski() throws Exception {
         KeyInfo ski = kifac.newKeyInfo(Collections.singletonList
             (kifac.newX509Data(Collections.singletonList
-            ("keyid".getBytes("ASCII")))));
+            ("keyid".getBytes(StandardCharsets.US_ASCII)))));
 
         test_create_signature_external(dsaSha1, ski, signingKey,
             KeySelector.singletonKeySelector(validatingKey), false);
@@ -327,7 +326,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
             (TransformParameterSpec) null);
 
         // create references
-        List<Reference> refs = new ArrayList<Reference>();
+        List<Reference> refs = new ArrayList<>();
 
         // Reference 1
         refs.add(fac.newReference("http://www.w3.org/TR/xml-stylesheet", sha1));
@@ -377,7 +376,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
             SignatureProperties.TYPE, null));
 
         // Reference 8
-        List<Transform> transforms = new ArrayList<Transform>();
+        List<Transform> transforms = new ArrayList<>();
         transforms.add(env);
         refs.add(fac.newReference("", sha1, transforms, null, null));
 
@@ -432,10 +431,10 @@ public class CreateBaltimore23Test extends org.junit.Assert {
             (Transform.XPATH, xpf)));
         KeyInfo ki = kifac.newKeyInfo(Collections.singletonList(rm), null);
 
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
 
         // create objects
-        List<XMLObject> objs = new ArrayList<XMLObject>();
+        List<XMLObject> objs = new ArrayList<>();
 
         // Object 1
         objs.add(fac.newXMLObject(Collections.singletonList
@@ -455,7 +454,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
             (new DOMStructure(nc)), "object-3", null, null));
 
         // Manifest
-        List<Reference> manRefs = new ArrayList<Reference>();
+        List<Reference> manRefs = new ArrayList<>();
 
         // Manifest Reference 1
         manRefs.add(fac.newReference("http://www.w3.org/TR/xml-stylesheet",
@@ -465,7 +464,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         manRefs.add(fac.newReference("#reference-1", sha1));
 
         // Manifest Reference 3
-        List<Transform> manTrans = new ArrayList<Transform>();
+        List<Transform> manTrans = new ArrayList<>();
         String xslt = ""
           + "<xsl:stylesheet xmlns:xsl='http://www.w3.org/1999/XSL/Transform'\n"
           + "		 xmlns='http://www.w3.org/TR/xhtml1/strict' \n"
@@ -493,7 +492,10 @@ public class CreateBaltimore23Test extends org.junit.Assert {
           + "    </html>\n"
           + "  </xsl:template>\n"
           + "</xsl:stylesheet>\n";
-        Document docxslt = db.parse(new ByteArrayInputStream(xslt.getBytes()));
+        Document docxslt = null;
+        try (InputStream is = new ByteArrayInputStream(xslt.getBytes())) {
+            docxslt = XMLUtils.read(is, false);
+        }
         Node xslElem = docxslt.getDocumentElement();
 
         manTrans.add(fac.newTransform(Transform.XSLT,
@@ -522,7 +524,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
             null, null));
 
         // Object 4
-        List<Object> xds = new ArrayList<Object>();
+        List<Object> xds = new ArrayList<>();
         xds.add("CN=Sean Mullan,DC=sun,DC=com");
         xds.add(kifac.newX509IssuerSerial
             ("CN=Sean Mullan,DC=sun,DC=com",
@@ -575,7 +577,6 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         dsc.setURIDereferencer(ud);
 
         sig.sign(dsc);
-        TestUtils.validateSecurityOrEncryptionElement(ys.getLastChild());
 
         // DOM L2 does not support the creation of DOCTYPEs, so instead
         // we insert it before the document using a StringWriter
@@ -594,8 +595,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
 
         // read document back into DOM tree
         try {
-            doc = XMLUtils.createDocumentBuilder(false).parse
-                (new InputSource(new StringReader(sw.toString())));
+            doc = XMLUtils.read(new InputSource(new StringReader(sw.toString())), false);
         } catch (SAXParseException spe) {
             System.err.println("line:" + spe.getLineNumber());
             System.err.println("xml:" + sw.toString());
@@ -655,7 +655,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         SignedInfo si = fac.newSignedInfo(withoutComments, sm,
             Collections.singletonList(ref));
 
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
 
         // create XMLSignature
         XMLSignature sig = fac.newXMLSignature(si, ki);
@@ -664,7 +664,6 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         dsc.setURIDereferencer(ud);
 
         sig.sign(dsc);
-        TestUtils.validateSecurityOrEncryptionElement(doc.getDocumentElement());
 
         /*
         System.out.println("doc is:");
@@ -708,7 +707,7 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         SignedInfo si = fac.newSignedInfo(withoutComments, sm,
             Collections.singletonList(ref));
 
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         // create Objects
         XMLObject obj = fac.newXMLObject(Collections.singletonList
             (new DOMStructure(doc.createTextNode("some text"))),
@@ -721,7 +720,6 @@ public class CreateBaltimore23Test extends org.junit.Assert {
         DOMSignContext dsc = new DOMSignContext(signingKey, doc);
 
         sig.sign(dsc);
-        TestUtils.validateSecurityOrEncryptionElement(doc.getDocumentElement());
 
         DOMValidateContext dvc = new DOMValidateContext
             (ks, doc.getDocumentElement());
