@@ -18,6 +18,7 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import java.nio.charset.StandardCharsets;
 import java.security.*;
 import java.security.spec.ECGenParameterSpec;
 import java.util.Collections;
@@ -28,19 +29,19 @@ import javax.xml.crypto.dsig.*;
 import javax.xml.crypto.dsig.dom.*;
 import javax.xml.crypto.dsig.keyinfo.*;
 import javax.xml.crypto.dsig.spec.*;
-import javax.xml.parsers.DocumentBuilder;
 
 import org.apache.xml.security.utils.XMLUtils;
 import org.w3c.dom.*;
 
 import javax.xml.crypto.test.KeySelectors;
 
+import static org.junit.Assert.assertTrue;
+
 /**
  * This is a testcase to generate all the W3C xmldsig XMLDSig11 testcases.
  *
- * @author Sean Mullan
  */
-public class CreateInteropXMLDSig11Test extends org.junit.Assert {
+public class CreateInteropXMLDSig11Test {
 
     private KeySelector kvks, sks;
     private CanonicalizationMethod withoutComments;
@@ -50,7 +51,6 @@ public class CreateInteropXMLDSig11Test extends org.junit.Assert {
                             hmacSha384, hmacSha512;
     private KeyInfo p256ki, p384ki, p521ki, rsaki, rsa2048ki;
     private XMLSignatureFactory fac;
-    private DocumentBuilder db;
     private KeyPair p256, p384, p521, rsa2048;
     private boolean ecSupport = true;
 
@@ -80,7 +80,6 @@ public class CreateInteropXMLDSig11Test extends org.junit.Assert {
         rsakpg.initialize(2048);
         rsa2048 = rsakpg.generateKeyPair();
 
-        db = XMLUtils.createDocumentBuilder(false);
         // create common objects
         fac = XMLSignatureFactory.getInstance("DOM", new org.apache.jcp.xml.dsig.internal.dom.XMLDSigRI());
         KeyInfoFactory kifac = fac.getKeyInfoFactory();
@@ -125,7 +124,7 @@ public class CreateInteropXMLDSig11Test extends org.junit.Assert {
         hmacSha512 = fac.newSignatureMethod
             ("http://www.w3.org/2001/04/xmldsig-more#hmac-sha512", null);
         kvks = new KeySelectors.KeyValueKeySelector();
-        sks = new KeySelectors.SecretKeySelector("testkey".getBytes("ASCII"));
+        sks = new KeySelectors.SecretKeySelector("testkey".getBytes(StandardCharsets.US_ASCII));
     }
 
     @org.junit.Test
@@ -264,21 +263,21 @@ public class CreateInteropXMLDSig11Test extends org.junit.Assert {
     public void test_create_enveloping_hmac_sha256() throws Exception {
         test_create_signature_enveloping(hmacSha256, sha1, rsaki,
                                          TestUtils.getSecretKey
-                                         ("testkey".getBytes("ASCII")), sks);
+                                         ("testkey".getBytes(StandardCharsets.US_ASCII)), sks);
     }
 
     @org.junit.Test
     public void test_create_enveloping_hmac_sha384() throws Exception {
         test_create_signature_enveloping(hmacSha384, sha1, rsaki,
                                          TestUtils.getSecretKey
-                                         ("testkey".getBytes("ASCII")), sks);
+                                         ("testkey".getBytes(StandardCharsets.US_ASCII)), sks);
     }
 
     @org.junit.Test
     public void test_create_enveloping_hmac_sha512() throws Exception {
         test_create_signature_enveloping(hmacSha512, sha1, rsaki,
                                          TestUtils.getSecretKey
-                                         ("testkey".getBytes("ASCII")), sks);
+                                         ("testkey".getBytes(StandardCharsets.US_ASCII)), sks);
     }
 
     private void test_create_signature_enveloping(
@@ -293,7 +292,7 @@ public class CreateInteropXMLDSig11Test extends org.junit.Assert {
         SignedInfo si = fac.newSignedInfo(withoutComments, sm,
                                           Collections.singletonList(ref));
 
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         // create Objects
         Element webElem = doc.createElementNS(null, "Web");
         Text text = doc.createTextNode("up up and away");
@@ -309,7 +308,6 @@ public class CreateInteropXMLDSig11Test extends org.junit.Assert {
         dsc.setDefaultNamespacePrefix("dsig");
 
         sig.sign(dsc);
-        TestUtils.validateSecurityOrEncryptionElement(doc.getDocumentElement());
 
         DOMValidateContext dvc = new DOMValidateContext
         (ks, doc.getDocumentElement());
