@@ -44,7 +44,6 @@ import javax.xml.crypto.dsig.keyinfo.KeyInfo;
 import javax.xml.crypto.dsig.keyinfo.KeyInfoFactory;
 import javax.xml.crypto.dsig.spec.C14NMethodParameterSpec;
 import javax.xml.crypto.test.KeySelectors;
-import javax.xml.parsers.DocumentBuilder;
 
 import org.apache.xml.security.utils.XMLUtils;
 import org.junit.BeforeClass;
@@ -52,10 +51,12 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
 
+import static org.junit.Assert.assertTrue;
+
 /**
  * Test signing using all available PublicKey signing algorithms
  */
-public class PKSignatureAlgorithmTest extends org.junit.Assert {
+public class PKSignatureAlgorithmTest {
 
     private KeySelector kvks;
     private CanonicalizationMethod withoutComments;
@@ -64,10 +65,10 @@ public class PKSignatureAlgorithmTest extends org.junit.Assert {
     private SignatureMethod rsaSha1Mgf1, rsaSha224Mgf1, rsaSha256Mgf1, rsaSha384Mgf1, rsaSha512Mgf1;
     private SignatureMethod ecdsaSha1, ecdsaSha224, ecdsaSha256, ecdsaSha384, ecdsaSha512, ecdsaRipemd160;
     private XMLSignatureFactory fac;
-    private DocumentBuilder db;
     private KeyPair rsaKeyPair, ecKeyPair;
     private KeyInfo rsaki, ecki;
     private boolean ecAlgParamsSupport = true;
+    private boolean isJDK11;
     private static boolean bcInstalled;
 
     static {
@@ -107,7 +108,6 @@ public class PKSignatureAlgorithmTest extends org.junit.Assert {
             ecAlgParamsSupport = false;
         }
 
-        db = XMLUtils.createDocumentBuilder(false);
         // create common objects
         fac = XMLSignatureFactory.getInstance("DOM", new org.apache.jcp.xml.dsig.internal.dom.XMLDSigRI());
         withoutComments = fac.newCanonicalizationMethod
@@ -155,6 +155,7 @@ public class PKSignatureAlgorithmTest extends org.junit.Assert {
             ecki = kifac.newKeyInfo(Collections.singletonList
                                 (kifac.newKeyValue(ecKeyPair.getPublic())));
         }
+        isJDK11 = System.getProperty("java.version").startsWith("11");
     }
 
     @org.junit.AfterClass
@@ -194,98 +195,84 @@ public class PKSignatureAlgorithmTest extends org.junit.Assert {
 
     @org.junit.Test
     public void testRSA_RIPEMD160() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
         test_create_signature_enveloping(rsaRipemd160, sha1, rsaki,
                                          rsaKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testRSA_SHA1_MGF1() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
         test_create_signature_enveloping(rsaSha1Mgf1, sha1, rsaki,
                                          rsaKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testRSA_SHA224_MGF1() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
         test_create_signature_enveloping(rsaSha224Mgf1, sha1, rsaki,
                                          rsaKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testRSA_SHA256_MGF1() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
         test_create_signature_enveloping(rsaSha256Mgf1, sha1, rsaki,
                                          rsaKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testRSA_SHA384_MGF1() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
         test_create_signature_enveloping(rsaSha384Mgf1, sha1, rsaki,
                                          rsaKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testRSA_SHA512_MGF1() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
         test_create_signature_enveloping(rsaSha512Mgf1, sha1, rsaki,
                                          rsaKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testECDSA_SHA1() throws Exception {
-        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null);
+        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null && !isJDK11);
         test_create_signature_enveloping(ecdsaSha1, sha1, ecki,
                                          ecKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testECDSA_SHA224() throws Exception {
-        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null);
+        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null && !isJDK11);
         test_create_signature_enveloping(ecdsaSha224, sha1, ecki,
                                          ecKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testECDSA_SHA256() throws Exception {
-        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null);
+        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null && !isJDK11);
         test_create_signature_enveloping(ecdsaSha256, sha1, ecki,
                                          ecKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testECDSA_SHA384() throws Exception {
-        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null);
+        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null && !isJDK11);
         test_create_signature_enveloping(ecdsaSha384, sha1, ecki,
                                          ecKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testECDSA_SHA512() throws Exception {
-        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null);
+        org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null && !isJDK11);
         test_create_signature_enveloping(ecdsaSha512, sha1, ecki,
                                          ecKeyPair.getPrivate(), kvks);
     }
 
     @org.junit.Test
     public void testECDSA_RIPEMD160() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
         org.junit.Assume.assumeTrue(ecAlgParamsSupport && ecki != null);
         test_create_signature_enveloping(ecdsaRipemd160, sha1, ecki,
                                          ecKeyPair.getPrivate(), kvks);
@@ -303,7 +290,7 @@ public class PKSignatureAlgorithmTest extends org.junit.Assert {
         SignedInfo si = fac.newSignedInfo(withoutComments, sm,
                                           Collections.singletonList(ref));
 
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         // create Objects
         Element webElem = doc.createElementNS(null, "Web");
         Text text = doc.createTextNode("up up and away");
