@@ -21,6 +21,8 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.*;
+
 import java.io.*;
 import java.security.MessageDigest;
 import java.security.Security;
@@ -37,9 +39,8 @@ import org.w3c.dom.Document;
 /**
  * Unit test for javax.xml.crypto.dsig.Reference
  *
- * @author Valerie Peng
  */
-public class ReferenceTest extends org.junit.Assert {
+public class ReferenceTest {
     private XMLSignatureFactory fac;
     private KeyInfoFactory kifac;
     private DigestMethod dmSHA1;
@@ -110,7 +111,7 @@ public class ReferenceTest extends org.junit.Assert {
             fail("Should throw a NPE instead of " + ex + " for null dm");
         }
 
-        String id  = "id";
+        String id = "id";
         String type = "type";
         try {
             ref = fac.newReference(uri, dmSHA1, null, type, id);
@@ -124,7 +125,7 @@ public class ReferenceTest extends org.junit.Assert {
             fail("Unexpected Exception: " + ex);
         }
 
-        List<Transform> transforms = new ArrayList<Transform>();
+        List<Transform> transforms = new ArrayList<>();
         try {
             // try empty transforms list
             ref = fac.newReference(uri, dmSHA1, transforms,
@@ -229,7 +230,6 @@ public class ReferenceTest extends org.junit.Assert {
                 (kifac.newKeyValue(TestUtils.getPublicKey(CRYPTO_ALGS[i])))));
             try {
                 sig.sign(signContext);
-                TestUtils.validateSecurityOrEncryptionElement(doc.getDocumentElement());
                 if (!cache) {
                     assertNull(ref.getDereferencedData());
                     assertNull(ref.getDigestInputStream());
@@ -262,7 +262,7 @@ public class ReferenceTest extends org.junit.Assert {
                         assertNotNull(validated_ref.getDigestInputStream());
                         assertTrue(digestInputEqual(validated_ref));
                     }
-                    byte[] dv =  validated_ref.getDigestValue();
+                    byte[] dv = validated_ref.getDigestValue();
                     byte[] cdv = validated_ref.getCalculatedDigestValue();
                     assertTrue(Arrays.equals(dv, cdv));
                     boolean valid = validated_ref.validate(validateContext);
