@@ -29,7 +29,9 @@ import org.w3c.dom.*;
 
 import javax.xml.crypto.test.KeySelectors;
 
-public class SecureXSLTTest extends org.junit.Assert {
+import static org.junit.Assert.assertFalse;
+
+public class SecureXSLTTest {
 
     static {
         Security.insertProviderAt
@@ -48,6 +50,7 @@ public class SecureXSLTTest extends org.junit.Assert {
         testSignature(new File(baseDir, "signature1.xml"));
     }
 
+    @org.junit.Test
     public void testSignature2() throws Exception {
 
         String fs = System.getProperty("file.separator");
@@ -59,6 +62,7 @@ public class SecureXSLTTest extends org.junit.Assert {
         testSignature(new File(baseDir, "signature2.xml"));
     }
 
+    @org.junit.Test
     public void testSignature3() throws Exception {
 
         String fs = System.getProperty("file.separator");
@@ -72,11 +76,11 @@ public class SecureXSLTTest extends org.junit.Assert {
 
     private void testSignature(File signatureFile) throws Exception {
 
-        XMLSignatureFactory fac = XMLSignatureFactory.getInstance("DOM");
+        XMLSignatureFactory fac = XMLSignatureFactory.getInstance("DOM", new org.apache.jcp.xml.dsig.internal.dom.XMLDSigRI());
         File f = new File("doc.xml");
 
         Document doc =
-            XMLUtils.createDocumentBuilder(false).parse(new FileInputStream(signatureFile));
+            XMLUtils.read(new FileInputStream(signatureFile), false);
 
         NodeList nl =
             doc.getElementsByTagNameNS(XMLSignature.XMLNS, "Signature");
