@@ -21,15 +21,16 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.*;
+
 import java.util.*;
 import javax.xml.crypto.dsig.*;
 
 /**
  * Unit test for javax.xml.crypto.dsig.SignatureProperties
  *
- * @author Valerie Peng
  */
-public class SignaturePropertiesTest extends org.junit.Assert {
+public class SignaturePropertiesTest {
 
     private XMLSignatureFactory factory;
     private String id = "id";
@@ -57,7 +58,7 @@ public class SignaturePropertiesTest extends org.junit.Assert {
             fail("Should raise a NPE for null content instead of " + ex);
         }
 
-        List<SignatureProperty> list = new ArrayList<SignatureProperty>();
+        List<SignatureProperty> list = new ArrayList<>();
         try {
             props = factory.newSignatureProperties(list, id);
             fail("Should raise an IAE for empty content");
@@ -98,7 +99,7 @@ public class SignaturePropertiesTest extends org.junit.Assert {
 
     @org.junit.Test
     public void testisFeatureSupported() {
-        List<SignatureProperty> list = new ArrayList<SignatureProperty>();
+        List<SignatureProperty> list = new ArrayList<>();
         list.add(prop);
         SignatureProperties props = factory.newSignatureProperties(list, id);
         try {
