@@ -21,6 +21,8 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.*;
+
 import java.util.*;
 import javax.xml.crypto.XMLStructure;
 import javax.xml.crypto.dsig.*;
@@ -28,9 +30,8 @@ import javax.xml.crypto.dsig.*;
 /**
  * Unit test for javax.xml.crypto.dsig.SignatureProperty
  *
- * @author Valerie Peng
  */
-public class SignaturePropertyTest extends org.junit.Assert {
+public class SignaturePropertyTest {
 
     private XMLSignatureFactory factory;
     private String target = "target";
@@ -54,7 +55,7 @@ public class SignaturePropertyTest extends org.junit.Assert {
         } catch (Exception ex) {
             fail("Should raise a NPE for null content instead of " + ex);
         }
-        List<XMLStructure> list = new ArrayList<XMLStructure>();
+        List<XMLStructure> list = new ArrayList<>();
         try {
             prop = factory.newSignatureProperty(list, target, id);
             fail("Should raise an IAE for empty content");
@@ -101,7 +102,7 @@ public class SignaturePropertyTest extends org.junit.Assert {
 
     @org.junit.Test
     public void testisFeatureSupported() {
-        List<XMLStructure> list = new ArrayList<XMLStructure>();
+        List<XMLStructure> list = new ArrayList<>();
         list.add(new TestUtils.MyOwnXMLStructure());
         SignatureProperty prop = factory.newSignatureProperty
             (list, target, id);
