@@ -21,6 +21,8 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.*;
+
 import java.security.Security;
 import java.util.*;
 import javax.xml.crypto.dsig.*;
@@ -29,9 +31,8 @@ import javax.xml.crypto.dsig.spec.C14NMethodParameterSpec;
 /**
  * Unit test for javax.xml.crypto.dsig.SignedInfo
  *
- * @author Valerie Peng
  */
-public class SignedInfoTest extends org.junit.Assert {
+public class SignedInfoTest {
     private XMLSignatureFactory fac;
     private CanonicalizationMethod cm;
     private SignatureMethod sm;
@@ -49,7 +50,7 @@ public class SignedInfoTest extends org.junit.Assert {
             (CanonicalizationMethod.INCLUSIVE_WITH_COMMENTS,
              (C14NMethodParameterSpec) null);
         sm = fac.newSignatureMethod(SignatureMethod.DSA_SHA1, null);
-        references = new ArrayList<Reference>();
+        references = new ArrayList<>();
         references.add(fac.newReference
                        ("http://www.sun.com/index.html",
                         fac.newDigestMethod(DigestMethod.SHA1, null)));
@@ -84,7 +85,7 @@ public class SignedInfoTest extends org.junit.Assert {
             }
         }
 
-        List<Reference> empty = new ArrayList<Reference>();
+        List<Reference> empty = new ArrayList<>();
         try {
             si = fac.newSignedInfo(cm, sm, empty);
             fail("Should throw an IAE for empty references");
