@@ -18,7 +18,10 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.*;
+
 import java.io.File;
+import java.nio.charset.StandardCharsets;
 import java.security.Security;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
@@ -37,9 +40,8 @@ import javax.xml.crypto.dsig.dom.DOMValidateContext;
 /**
  * This is a testcase that validates various signatures
  *
- * @author Sean Mullan
  */
-public class ValidateSignatureTest extends org.junit.Assert {
+public class ValidateSignatureTest {
 
     private SignatureValidator validator;
     private File dir;
@@ -80,7 +82,7 @@ public class ValidateSignatureTest extends org.junit.Assert {
         String file = "signature-external-c14n-xmlatrs.xml";
 
         boolean coreValidity = validator.validate(file,
-            new KeySelectors.SecretKeySelector("secret".getBytes("ASCII")));
+            new KeySelectors.SecretKeySelector("secret".getBytes(StandardCharsets.US_ASCII)));
         assertTrue("Signature failed core validation", coreValidity);
     }
 
@@ -102,7 +104,7 @@ public class ValidateSignatureTest extends org.junit.Assert {
         try {
             validator.validate
                 ("signature-enveloping-hmac-sha1-trunclen-0-attack.xml",
-                new KeySelectors.SecretKeySelector("secret".getBytes("ASCII")));
+                new KeySelectors.SecretKeySelector("secret".getBytes(StandardCharsets.US_ASCII)));
             fail("Expected HMACOutputLength exception");
         } catch (XMLSignatureException xse) {
             // System.out.println(xse.getMessage());
@@ -116,7 +118,7 @@ public class ValidateSignatureTest extends org.junit.Assert {
         try {
             validator.validate
                 ("signature-enveloping-hmac-sha1-trunclen-8-attack.xml",
-                new KeySelectors.SecretKeySelector("secret".getBytes("ASCII")));
+                new KeySelectors.SecretKeySelector("secret".getBytes(StandardCharsets.US_ASCII)));
             fail("Expected HMACOutputLength exception");
         } catch (XMLSignatureException xse) {
             // System.out.println(xse.getMessage());
