@@ -21,6 +21,8 @@
  */
 package javax.xml.crypto.test.dsig;
 
+import static org.junit.Assert.*;
+
 import java.io.*;
 import java.util.*;
 import java.security.*;
@@ -40,10 +42,8 @@ import org.w3c.dom.*;
 /**
  * Unit test for javax.xml.crypto.dsig.XMLSignature
  *
- * @version $Id$
- * @author Valerie Peng
  */
-public class XMLSignatureTest extends org.junit.Assert {
+public class XMLSignatureTest {
     private XMLSignatureFactory fac;
     private KeyInfoFactory kifac;
     private SignedInfo defSi;
@@ -96,8 +96,8 @@ public class XMLSignatureTest extends org.junit.Assert {
     @org.junit.Test
     public void testConstructor() throws Exception {
         XMLSignature sig = null;
-        // test  XMLSignatureFactory.newXMLSignature(SignedInfo, KeyInfo)
-        // and  XMLSignatureFactory.newXMLSignature(SignedInfo,
+        // test XMLSignatureFactory.newXMLSignature(SignedInfo, KeyInfo)
+        // and XMLSignatureFactory.newXMLSignature(SignedInfo,
         //          KeyInfo, List, String, String)
         // for generating XMLSignature objects
         for (int i = 0; i < 2; i++) {
@@ -180,7 +180,6 @@ public class XMLSignatureTest extends org.junit.Assert {
             signContext = new DOMSignContext(SIGN_KEYS[i], doc);
             signContext.setURIDereferencer(ud);
             sig.sign(signContext);
-            TestUtils.validateSecurityOrEncryptionElement(doc.getDocumentElement());
             validateContext = new DOMValidateContext
                 (VALIDATE_KEYS[i], doc.getDocumentElement());
             validateContext.setURIDereferencer(ud);
@@ -199,7 +198,7 @@ public class XMLSignatureTest extends org.junit.Assert {
         KeyInfo ki = null;
         XMLSignContext signContext;
         Provider p = new TestProvider();
-        for (int i = SIGN_KEYS.length-2; i>=0 ; i--) {
+        for (int i = SIGN_KEYS.length-1; i>=0 ; i--) {
             si = createSignedInfo(SIG_METHODS[i]);
             if (VALIDATE_KEYS[i] instanceof PublicKey) {
                 ki = kifac.newKeyInfo(Collections.singletonList
@@ -211,12 +210,15 @@ public class XMLSignatureTest extends org.junit.Assert {
             sig = fac.newXMLSignature(si, ki, objs, id, sigValueId);
             Document doc = TestUtils.newDocument();
             signContext = new DOMSignContext(SIGN_KEYS[i], doc);
-            signContext.setProperty
-                ("org.jcp.xml.dsig.internal.dom.SignatureProvider", p);
+            if (SIGN_KEYS[i] instanceof PrivateKey) {
+                signContext.setProperty("org.jcp.xml.dsig.internal.dom.SignatureProvider", p);
+            } else {
+                signContext.setProperty("org.jcp.xml.dsig.internal.dom.MacProvider", p);
+            }
+
             signContext.setURIDereferencer(ud);
             try {
                 sig.sign(signContext);
-                // note - don't bother validating the returned XML here, because there shouldn't be any.
                 fail("Should have failed because TestProvider does not " +
                      "support " + SIGN_KEYS[i].getAlgorithm());
             } catch (Exception e) {
@@ -229,7 +231,7 @@ public class XMLSignatureTest extends org.junit.Assert {
     @org.junit.Test
     public void testSignWithEmptyNSPrefix() throws Exception {
         SignedInfo si = createSignedInfo(SIG_METHODS[1]);
-        KeyInfo	ki = kifac.newKeyInfo(Collections.singletonList
+        KeyInfo ki = kifac.newKeyInfo(Collections.singletonList
                     (kifac.newKeyValue((PublicKey) VALIDATE_KEYS[1])));
         XMLSignature sig = fac.newXMLSignature(si, ki, objs, id, sigValueId);
         Document doc = TestUtils.newDocument();
@@ -237,7 +239,6 @@ public class XMLSignatureTest extends org.junit.Assert {
         signContext.putNamespacePrefix(XMLSignature.XMLNS, "");
         signContext.setURIDereferencer(ud);
         sig.sign(signContext);
-        TestUtils.validateSecurityOrEncryptionElement(doc.getDocumentElement());
 /*
         StringWriter sw = new StringWriter();
         dumpDocument(doc, sw);
@@ -257,7 +258,7 @@ public class XMLSignatureTest extends org.junit.Assert {
         SignedInfo si = fac.newSignedInfo(cm, SIG_METHODS[1], refs);
 
         // create objects
-        List<XMLObject> objs = new ArrayList<XMLObject>();
+        List<XMLObject> objs = new ArrayList<>();
 
         // Object 1
         List<Reference> manRefs = Collections.singletonList
@@ -273,7 +274,7 @@ public class XMLSignatureTest extends org.junit.Assert {
         objs.add(fac.newXMLObject(Collections.singletonList
             (new DOMStructure(nc)), "object-2", null, null));
 
-        KeyInfo	ki = kifac.newKeyInfo(Collections.singletonList
+        KeyInfo ki = kifac.newKeyInfo(Collections.singletonList
                     (kifac.newKeyValue((PublicKey) VALIDATE_KEYS[1])));
 
         // create XMLSignature
@@ -281,7 +282,6 @@ public class XMLSignatureTest extends org.junit.Assert {
         DOMSignContext dsc = new DOMSignContext(SIGN_KEYS[1], doc);
 
         sig.sign(dsc);
-        TestUtils.validateSecurityOrEncryptionElement(doc.getDocumentElement());
 
 /*
         StringWriter sw = new StringWriter();
@@ -310,7 +310,7 @@ public class XMLSignatureTest extends org.junit.Assert {
         File f = new File(base + "/src/test/resources/javax/xml/crypto/dsig/" +
             "signature-enveloping-rsa-template.xml");
 
-        Document doc = XMLUtils.createDocumentBuilder(false).parse(new FileInputStream(f));
+        Document doc = XMLUtils.read(new FileInputStream(f), false);
 
         // Find Signature element
         NodeList nl =
@@ -333,7 +333,6 @@ public class XMLSignatureTest extends org.junit.Assert {
         // remove the signature node (since it will get recreated)
         parent.removeChild(domSignature.getNode());
         newSignature.sign(signContext);
-        TestUtils.validateSecurityOrEncryptionElement(parent.getLastChild());
 
         // check that Object element retained namespace definitions
         Element objElem = (Element)parent.getFirstChild().getLastChild();
@@ -361,7 +360,7 @@ public class XMLSignatureTest extends org.junit.Assert {
             (new DOMStructure(doc.createTextNode("I am the text."))),
             "", "text/plain", null);
 
-        KeyInfo	ki = kifac.newKeyInfo(Collections.singletonList
+        KeyInfo ki = kifac.newKeyInfo(Collections.singletonList
                     (kifac.newKeyValue((PublicKey) VALIDATE_KEYS[1])));
 
         // create XMLSignature
@@ -386,7 +385,7 @@ public class XMLSignatureTest extends org.junit.Assert {
         SignatureMethod sm = fac.newSignatureMethod(DSA_SHA256, null);
         SignedInfo si = createSignedInfo(sm);
         KeyInfo ki = kifac.newKeyInfo(Collections.singletonList
-            (kifac.newKeyValue((PublicKey)TestUtils.getPublicKey("DSA", 2048))));
+            (kifac.newKeyValue(TestUtils.getPublicKey("DSA", 2048))));
         XMLSignature sig = fac.newXMLSignature(si, ki, objs, id, sigValueId);
         Document doc = TestUtils.newDocument();
         XMLSignContext signContext =
