@@ -21,19 +21,20 @@
  */
 package javax.xml.crypto.test.dsig.keyinfo;
 
+import static org.junit.Assert.*;
+
 import java.security.*;
 import javax.xml.crypto.dsig.keyinfo.*;
 
 /**
  * Unit test for javax.xml.crypto.dsig.keyinfo.KeyValue
  *
- * @author Valerie Peng
  */
-public class KeyValueTest extends org.junit.Assert {
+public class KeyValueTest {
 
     private static final String[] ALGOS = { "DSA", "RSA" };
     private KeyInfoFactory fac;
-    private PublicKey keys[] = null;
+    private PublicKey keys[];
 
     public KeyValueTest() throws Exception {
         fac = KeyInfoFactory.getInstance
