@@ -21,6 +21,8 @@
  */
 package javax.xml.crypto.test.dsig.keyinfo;
 
+import static org.junit.Assert.*;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -30,9 +32,8 @@ import javax.xml.crypto.dsig.keyinfo.*;
 /**
  * Unit test for javax.xml.crypto.dsig.keyinfo.PGPData
  *
- * @author Valerie Peng
  */
-public class PGPDataTest extends org.junit.Assert {
+public class PGPDataTest {
 
     private KeyInfoFactory fac;
     private byte[][] values = {
