@@ -18,14 +18,16 @@
  */
 package org.apache.xml.security.test.dom.c14n.implementations;
 
+import static org.junit.Assert.*;
+
 import java.io.File;
+import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.StringReader;
 import java.util.HashSet;
 import java.util.Set;
 
-import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.TransformerException;
 import javax.xml.xpath.XPath;
@@ -57,26 +59,18 @@ import org.xml.sax.SAXException;
 
 
 /**
- * @author Christian Geuer-Pollmann
  */
-public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
+public class Canonicalizer20010315ExclusiveTest {
 
     static {
         org.apache.xml.security.Init.init();
     }
 
-    static org.slf4j.Logger log =
+    static org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(
             Canonicalizer20010315ExclusiveTest.class
         );
 
-    /** Field db */
-    DocumentBuilder db;
-
-    public Canonicalizer20010315ExclusiveTest() throws ParserConfigurationException {
-        this.db = XMLUtils.createDocumentBuilder(false);
-    }
-
     /**
      * Method testA
      *
@@ -105,12 +99,12 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         // File fileIn = new File("signature.xml");
         assertTrue("file exists", fileIn.exists());
 
-        Document doc = this.db.parse(fileIn);
+        Document doc = XMLUtils.read(new FileInputStream(fileIn), false);
         Element signatureElement =
             (Element) doc.getElementsByTagNameNS(
                 Constants.SignatureSpecNS, Constants._TAG_SIGNATURE).item(0);
         XMLSignature xmlSignature = new XMLSignature(signatureElement,
-                                                     fileIn.toURI().toURL().toString());
+                                                     fileIn.toURI().toURL().toString(), false);
         boolean verify =
             xmlSignature.checkSignatureValue(xmlSignature.getKeyInfo().getPublicKey());
         int length = xmlSignature.getSignedInfo().getLength();
@@ -150,8 +144,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         XMLSignatureException, XMLSecurityException {
 
         Document doc =
-            this.db.parse(
-                getAbsolutePath("src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_1.xml")
+            XMLUtils.read(
+                new FileInputStream(getAbsolutePath("src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_1.xml")),
+                false
             );
         Node root = doc.getElementsByTagNameNS("http://example.net", "elem2").item(0);
         Canonicalizer20010315 c = new Canonicalizer20010315WithComments();
@@ -183,9 +178,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         InvalidCanonicalizerException, TransformerException,
         XMLSignatureException, XMLSecurityException {
         Document doc =
-            this.db.parse(getAbsolutePath(
+            XMLUtils.read(new FileInputStream(getAbsolutePath(
                 "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_2.xml")
-            );
+            ), false);
         Node root = doc.getElementsByTagNameNS("http://example.net", "elem2").item(0);
         Canonicalizer20010315 c = new Canonicalizer20010315WithComments();
         byte[] reference = JavaUtils.getBytesFromFile(getAbsolutePath(
@@ -216,8 +211,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         InvalidCanonicalizerException, TransformerException,
         XMLSignatureException, XMLSecurityException {
         Document doc =
-            this.db.parse(getAbsolutePath(
-                "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_1.xml"));
+            XMLUtils.read(new FileInputStream(getAbsolutePath(
+                "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_1.xml")),
+                          false);
         Node root = doc.getElementsByTagNameNS("http://example.net", "elem2").item(0);
         Canonicalizer20010315Excl c = new Canonicalizer20010315ExclWithComments();
         byte[] reference = JavaUtils.getBytesFromFile(getAbsolutePath(
@@ -248,8 +244,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         InvalidCanonicalizerException, TransformerException,
         XMLSignatureException, XMLSecurityException {
         Document doc =
-            this.db.parse(getAbsolutePath(
-                "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_2.xml"));
+            XMLUtils.read(new FileInputStream(getAbsolutePath(
+                "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_2.xml")),
+                          false);
         Node root = doc.getElementsByTagNameNS("http://example.net", "elem2").item(0);
         Canonicalizer20010315Excl c = new Canonicalizer20010315ExclWithComments();
         byte[] reference = JavaUtils.getBytesFromFile(getAbsolutePath(
@@ -283,8 +280,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         InvalidCanonicalizerException, TransformerException,
         XMLSignatureException, XMLSecurityException, XPathExpressionException {
         Document doc =
-            this.db.parse(getAbsolutePath(
-                "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_3.xml"));
+            XMLUtils.read(new FileInputStream(getAbsolutePath(
+                "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_2_3.xml")),
+                          false);
 
         XPathFactory xpf = XPathFactory.newInstance();
         XPath xpath = xpf.newXPath();
@@ -335,10 +333,10 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
             + "</ns0:Ping>"
             + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         Canonicalizer20010315ExclOmitComments c14n =
             new Canonicalizer20010315ExclOmitComments();
-        Set<Node> nodeSet = new HashSet<Node>();
+        Set<Node> nodeSet = new HashSet<>();
         XMLUtils.getSet(doc.getDocumentElement().getFirstChild(), nodeSet, null, false);
         XMLSignatureInput input = new XMLSignatureInput(nodeSet);
         byte[] bytes = c14n.engineCanonicalize(input, "env ns0 xsi wsu");
@@ -353,9 +351,10 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
     @org.junit.Test
     public void test24excl() throws Exception {
         Document doc =
-            this.db.parse(
-                getAbsolutePath(
-                    "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_4.xml"));
+            XMLUtils.read(
+                new FileInputStream(getAbsolutePath(
+                    "src/test/resources/org/apache/xml/security/c14n/inExcl/example2_4.xml")),
+                false);
         Node root =
             doc.getElementsByTagNameNS("http://example.net", "elem2").item(0);
         Canonicalizer20010315Excl c = new Canonicalizer20010315ExclWithComments();
@@ -375,7 +374,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
      */
     @org.junit.Test
     public void test24Aexcl() throws Exception {
-        Document doc = XMLUtils.createDocumentBuilder(false).newDocument();
+        Document doc = XMLUtils.newDocument();
         Element local = doc.createElementNS("foo:bar", "dsig:local");
         Element test = doc.createElementNS("http://example.net", "etsi:test");
         Element elem2 = doc.createElementNS("http://example.net", "etsi:elem2");
@@ -428,7 +427,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         {
             Canonicalizer20010315ExclOmitComments c14n =
                     new Canonicalizer20010315ExclOmitComments();
@@ -491,7 +490,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         {
             Canonicalizer20010315ExclOmitComments c14n =
                     new Canonicalizer20010315ExclOmitComments();
@@ -541,7 +540,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         {
             Canonicalizer20010315ExclOmitComments c14n =
                     new Canonicalizer20010315ExclOmitComments();
@@ -591,7 +590,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         {
             Canonicalizer20010315ExclOmitComments c14n =
                     new Canonicalizer20010315ExclOmitComments();
@@ -641,7 +640,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         Canonicalizer20010315ExclOmitComments c14n =
                 new Canonicalizer20010315ExclOmitComments();
         byte[] bytes = c14n.engineCanonicalizeSubTree(doc.getDocumentElement().getFirstChild(), "#default", true);
@@ -676,7 +675,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         Canonicalizer20010315ExclOmitComments c14n =
                 new Canonicalizer20010315ExclOmitComments();
         byte[] bytes = c14n.engineCanonicalizeSubTree(doc.getDocumentElement().getFirstChild(), "#default", true);
@@ -711,7 +710,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         Canonicalizer20010315ExclOmitComments c14n =
                 new Canonicalizer20010315ExclOmitComments();
         byte[] bytes = c14n.engineCanonicalizeSubTree(doc.getDocumentElement().getFirstChild(), "#default", true);
@@ -746,7 +745,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>"
                         + "</env:Body>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         Canonicalizer20010315ExclOmitComments c14n =
                 new Canonicalizer20010315ExclOmitComments();
         byte[] bytes = c14n.engineCanonicalizeSubTree(doc.getDocumentElement().getFirstChild(), "#default", true);
@@ -776,7 +775,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "<ns0:text xsi:type=\"xsd:string\">hello</ns0:text>"
                         + "</ns0:Ping>";
 
-        Document doc = this.db.parse(new InputSource(new StringReader(XML)));
+        Document doc = XMLUtils.read(new InputSource(new StringReader(XML)), false);
         Canonicalizer20010315ExclOmitComments c14n =
                 new Canonicalizer20010315ExclOmitComments();
         byte[] bytes = c14n.engineCanonicalizeSubTree(doc.getDocumentElement().getFirstChild().getFirstChild(), "#default", true);
