@@ -18,18 +18,20 @@
  */
 package org.apache.xml.security.test.dom.encryption;
 
+import static org.junit.Assert.*;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
-import java.lang.reflect.Constructor;
+import java.io.FileInputStream;
+import java.io.InputStream;
+import java.nio.charset.StandardCharsets;
 import java.security.Key;
 import java.security.KeyPairGenerator;
 import java.security.KeyPair;
 import java.security.NoSuchAlgorithmException;
 import java.security.PrivateKey;
-import java.security.Provider;
 import java.security.PublicKey;
-import java.security.Security;
 
 import javax.crypto.Cipher;
 import javax.crypto.KeyGenerator;
@@ -38,7 +40,6 @@ import javax.crypto.SecretKey;
 import javax.crypto.SecretKeyFactory;
 import javax.crypto.spec.DESedeKeySpec;
 import javax.crypto.spec.SecretKeySpec;
-import javax.xml.parsers.DocumentBuilder;
 
 import org.apache.xml.security.algorithms.JCEMapper;
 import org.apache.xml.security.c14n.Canonicalizer;
@@ -61,12 +62,10 @@ import org.w3c.dom.NodeList;
 
 /**
  *
- * @author  Axl Mattheus
- * @author  Berin Lautenbach
  */
-public class XMLCipherTest extends org.junit.Assert {
+public class XMLCipherTest {
 
-    private static org.slf4j.Logger log =
+    private static final org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(XMLCipherTest.class);
 
     static {
@@ -114,31 +113,6 @@ public class XMLCipherTest extends org.junit.Assert {
 
         haveKeyWraps =
             JCEMapper.translateURItoJCEID(EncryptionConstants.ALGO_ID_KEYWRAP_AES128) != null;
-
-        //
-        // If the BouncyCastle provider is not installed, then try to load it
-        // via reflection.
-        //
-        if (Security.getProvider("BC") == null) {
-            Constructor<?> cons = null;
-            try {
-                Class<?> c = Class.forName("org.bouncycastle.jce.provider.BouncyCastleProvider");
-                cons = c.getConstructor(new Class[] {});
-            } catch (Exception e) {
-                //ignore
-            }
-            if (cons != null) {
-                Provider provider = (Provider)cons.newInstance();
-                Security.insertProviderAt(provider, 2);
-                bcInstalled = true;
-            }
-        }
-
-    }
-
-    @org.junit.AfterClass
-    public static void cleanup() throws Exception {
-        Security.removeProvider("BC");
     }
 
     /**
@@ -199,7 +173,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testAES128ElementAES192KWCipherUsingKEK skipped as "
                 + "necessary algorithms not available"
             );
@@ -255,8 +229,8 @@ public class XMLCipherTest extends org.junit.Assert {
             builderKeyInfo.add(encryptedKey);
 
             ed = cipher.doFinal(d, e);
-            log.debug("Encrypted document");
-            log.debug(toString(ed));
+            LOG.debug("Encrypted document");
+            LOG.debug(toString(ed));
 
 
             //decrypt
@@ -270,7 +244,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testAES256ElementRSAKWCipherUsingKEK skipped as "
                 + "necessary algorithms not available"
             );
@@ -357,7 +331,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testAES192Element3DESKWCipher skipped as "
                 + "necessary algorithms not available"
             );
@@ -401,7 +375,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testTripleDesElementCipher skipped as necessary algorithms not available"
             );
         }
@@ -445,7 +419,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testAes128ElementCipher skipped as necessary algorithms not available"
             );
         }
@@ -491,7 +465,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn("Test testAes192ElementCipher skipped as necessary algorithms not available");
+            LOG.warn("Test testAes192ElementCipher skipped as necessary algorithms not available");
         }
     }
 
@@ -537,7 +511,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn("Test testAes265ElementCipher skipped as necessary algorithms not available");
+            LOG.warn("Test testAes265ElementCipher skipped as necessary algorithms not available");
         }
     }
 
@@ -579,7 +553,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testTripleDesDocumentCipher skipped as "
                 + "necessary algorithms not available"
             );
@@ -637,7 +611,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testTripleDesDocumentCipher skipped as "
                 + "necessary algorithms not available"
             );
@@ -651,9 +625,7 @@ public class XMLCipherTest extends org.junit.Assert {
     public void testSameDocumentCipherReference() throws Exception {
 
         if (haveISOPadding) {
-            DocumentBuilder db = XMLUtils.createDocumentBuilder(false);
-
-            Document d = db.newDocument();
+            Document d = XMLUtils.newDocument();
 
             Element docElement = d.createElement("EncryptedDoc");
             d.appendChild(docElement);
@@ -702,15 +674,15 @@ public class XMLCipherTest extends org.junit.Assert {
 
             // Now the decrypt, with a brand new cipher
             XMLCipher cipherDecrypt = XMLCipher.getInstance();
-            Key key = new SecretKeySpec("abcdefghijklmnop".getBytes("ASCII"), "AES");
+            Key key = new SecretKeySpec("abcdefghijklmnop".getBytes(StandardCharsets.US_ASCII), "AES");
 
             cipherDecrypt.init(XMLCipher.DECRYPT_MODE, key);
             byte[] decryptBytes = cipherDecrypt.decryptToByteArray(ee);
 
             assertEquals("A test encrypted secret",
-                        new String(decryptBytes, "ASCII"));
+                        new String(decryptBytes, StandardCharsets.US_ASCII));
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testSameDocumentCipherReference skipped as "
                 + "necessary algorithms not available"
             );
@@ -724,8 +696,6 @@ public class XMLCipherTest extends org.junit.Assert {
     public void testPhysicalRepresentation() throws Exception {
 
         if (haveISOPadding) {
-            DocumentBuilder db = XMLUtils.createDocumentBuilder(false);
-
             byte[] bits192 = "abcdefghijklmnopqrstuvwx".getBytes();
             DESedeKeySpec keySpec = new DESedeKeySpec(bits192);
             SecretKeyFactory keyFactory = SecretKeyFactory.getInstance("DESede");
@@ -734,7 +704,10 @@ public class XMLCipherTest extends org.junit.Assert {
             // Test inherited namespaces don't add extra attributes
             // Test unused namespaces are preserved
             final String DATA1 = "<ns:root xmlns:ns=\"ns.com\"><ns:elem xmlns:ns2=\"ns2.com\">11</ns:elem></ns:root>";
-            Document doc = db.parse(new ByteArrayInputStream(DATA1.getBytes("UTF8")));
+            Document doc = null;
+            try (InputStream is = new ByteArrayInputStream(DATA1.getBytes(StandardCharsets.UTF_8))) {
+                doc = XMLUtils.read(is, false);
+            }
             Element elem = (Element)doc.getDocumentElement().getFirstChild();
 
             XMLCipher dataCipher = XMLCipher.getInstance(XMLCipher.TRIPLEDES);
@@ -758,7 +731,9 @@ public class XMLCipherTest extends org.junit.Assert {
 
             // Test default namespace undeclaration is preserved
             final String DATA2 = "<ns:root xmlns=\"defns.com\" xmlns:ns=\"ns.com\"><elem xmlns=\"\">11</elem></ns:root>";
-            doc = db.parse(new ByteArrayInputStream(DATA2.getBytes("UTF8")));
+            try (InputStream is = new ByteArrayInputStream(DATA2.getBytes(StandardCharsets.UTF_8))) {
+                doc = XMLUtils.read(is, false);
+            }
             elem = (Element)doc.getDocumentElement().getFirstChild();
 
             dataCipher = XMLCipher.getInstance(XMLCipher.TRIPLEDES);
@@ -783,8 +758,10 @@ public class XMLCipherTest extends org.junit.Assert {
             // Test comments and PIs are not treated specially when serializing element content.
             // Other c14n algorithms add a newline after comments and PIs, when they are before or after the document element.
             final String DATA3 = "<root><!--comment1--><?pi1 target1?><elem/><!--comment2--><?pi2 target2?></root>";
-            doc = db.parse(new ByteArrayInputStream(DATA3.getBytes("UTF8")));
-            elem = (Element)doc.getDocumentElement();
+            try (InputStream is = new ByteArrayInputStream(DATA3.getBytes(StandardCharsets.UTF_8))) {
+                doc = XMLUtils.read(is, false);
+            }
+            elem = doc.getDocumentElement();
 
             dataCipher = XMLCipher.getInstance(XMLCipher.TRIPLEDES);
             dataCipher.init(XMLCipher.ENCRYPT_MODE, secretKey);
@@ -811,7 +788,7 @@ public class XMLCipherTest extends org.junit.Assert {
             n = n.getNextSibling();
             assertNull(n);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testPhysicalRepresentation skipped as "
                 + "necessary algorithms not available"
             );
@@ -821,7 +798,7 @@ public class XMLCipherTest extends org.junit.Assert {
     @org.junit.Test
     public void testSerializedData() throws Exception {
         if (!haveISOPadding) {
-            log.warn("Test testSerializedData skipped as necessary algorithms not available");
+            LOG.warn("Test testSerializedData skipped as necessary algorithms not available");
             return;
         }
 
@@ -847,13 +824,13 @@ public class XMLCipherTest extends org.junit.Assert {
         canon.notReset();
         canon.canonicalizeSubtree(e);
         baos.close();
-        String before = baos.toString("UTF-8");
+        String before = baos.toString(StandardCharsets.UTF_8.name());
 
         byte[] serialized = baos.toByteArray();
-        EncryptedData encryptedData =
-            cipher.encryptData(
-                d, EncryptionConstants.TYPE_ELEMENT, new ByteArrayInputStream(serialized)
-            );
+        EncryptedData encryptedData = null;
+        try (InputStream is = new ByteArrayInputStream(serialized)) {
+            encryptedData = cipher.encryptData(d, EncryptionConstants.TYPE_ELEMENT, is);
+        }
 
         //decrypt
         XMLCipher dcipher = XMLCipher.getInstance(XMLCipher.AES_128);
@@ -861,11 +838,13 @@ public class XMLCipherTest extends org.junit.Assert {
         String algorithm = encryptedData.getEncryptionMethod().getAlgorithm();
         assertEquals(XMLCipher.AES_128, algorithm);
         byte[] bytes = dcipher.decryptToByteArray(dcipher.martial(encryptedData));
-        String after = new String(bytes, "UTF-8");
+        String after = new String(bytes, StandardCharsets.UTF_8);
         assertEquals(before, after);
 
         // test with null type
-        encryptedData = cipher.encryptData(d, null, new ByteArrayInputStream(serialized));
+        try (InputStream is = new ByteArrayInputStream(serialized)) {
+            encryptedData = cipher.encryptData(d, null, is);
+        }
     }
 
     @org.junit.Test
@@ -877,8 +856,7 @@ public class XMLCipherTest extends org.junit.Assert {
         }
         File f = new File(filename);
 
-        DocumentBuilder builder = XMLUtils.createDocumentBuilder(false);
-        Document document = builder.parse(f);
+        Document document = XMLUtils.read(new FileInputStream(f), false);
 
         XMLCipher keyCipher = XMLCipher.getInstance();
         keyCipher.init(XMLCipher.UNWRAP_MODE, null);
@@ -896,9 +874,8 @@ public class XMLCipherTest extends org.junit.Assert {
 
     @org.junit.Test
     public void testEecryptToByteArray() throws Exception {
-        if (!bcInstalled) {
-            return;
-        }
+        org.junit.Assume.assumeTrue(bcInstalled);
+
         KeyGenerator keygen = KeyGenerator.getInstance("AES");
         keygen.init(128);
         Key key = keygen.generateKey();
@@ -980,7 +957,7 @@ public class XMLCipherTest extends org.junit.Assert {
             target = toString(dd);
             assertEquals(source, target);
         } else {
-            log.warn(
+            LOG.warn(
                 "Test testAES128ElementAES192KWCipherUsingKEK skipped as "
                 + "necessary algorithms not available"
             );
@@ -996,15 +973,14 @@ public class XMLCipherTest extends org.junit.Assert {
         baos.write(serBytes);
         baos.close();
 
-        return baos.toString("UTF-8");
+        return baos.toString(StandardCharsets.UTF_8.name());
     }
 
     private Document document() {
         Document d = null;
         try {
-            DocumentBuilder db = XMLUtils.createDocumentBuilder(false);
             File f = new File(documentName);
-            d = db.parse(f);
+            d = XMLUtils.read(new FileInputStream(f), false);
         } catch (Exception e) {
             e.printStackTrace();
             System.exit(-1);
