@@ -18,9 +18,13 @@
  */
 package org.apache.xml.security.test.dom.signature;
 
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.FileInputStream;
+import java.io.InputStream;
 import java.security.KeyPair;
 import java.security.KeyPairGenerator;
 import java.security.KeyStore;
@@ -32,12 +36,16 @@ import javax.xml.xpath.XPath;
 import javax.xml.xpath.XPathConstants;
 import javax.xml.xpath.XPathFactory;
 
+import org.apache.xml.security.algorithms.MessageDigestAlgorithm;
 import org.apache.xml.security.algorithms.SignatureAlgorithm;
 import org.apache.xml.security.c14n.Canonicalizer;
 import org.apache.xml.security.keys.KeyInfo;
 import org.apache.xml.security.signature.ObjectContainer;
+import org.apache.xml.security.signature.SignatureProperties;
+import org.apache.xml.security.signature.SignatureProperty;
 import org.apache.xml.security.signature.SignedInfo;
 import org.apache.xml.security.signature.XMLSignature;
+import org.apache.xml.security.signature.XMLSignatureException;
 import org.apache.xml.security.test.dom.DSNamespaceContext;
 import org.apache.xml.security.transforms.Transforms;
 import org.apache.xml.security.transforms.params.XPath2FilterContainer;
@@ -51,21 +59,18 @@ import org.w3c.dom.Element;
 /**
  * Tests that create signatures.
  *
- * @author Sean Mullan
  */
-public class CreateSignatureTest extends org.junit.Assert {
+public class CreateSignatureTest {
 
-    static org.slf4j.Logger log =
+    static org.slf4j.Logger LOG =
         org.slf4j.LoggerFactory.getLogger(CreateSignatureTest.class);
 
     private static final String BASEDIR = System.getProperty("basedir");
     private static final String SEP = System.getProperty("file.separator");
 
-    private KeyPair kp = null;
-    private javax.xml.parsers.DocumentBuilder db;
+    private KeyPair kp;
 
     public CreateSignatureTest() throws Exception {
-        db = XMLUtils.createDocumentBuilder(false);
         org.apache.xml.security.Init.init();
         kp = KeyPairGenerator.getInstance("RSA").genKeyPair();
     }
@@ -76,7 +81,7 @@ public class CreateSignatureTest extends org.junit.Assert {
      */
     @org.junit.Test
     public void testEmptyNodeSet() throws Exception {
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         Element envelope = doc.createElementNS("http://www.usps.gov/", "Envelope");
         envelope.appendChild(doc.createTextNode("\n"));
         doc.appendChild(envelope);
@@ -151,7 +156,7 @@ public class CreateSignatureTest extends org.junit.Assert {
 
     @org.junit.Test
     public void testXFilter2Signature() throws Exception {
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         doc.appendChild(doc.createComment(" Comment before "));
         Element root = doc.createElementNS("", "RootElement");
 
@@ -193,7 +198,9 @@ public class CreateSignatureTest extends org.junit.Assert {
         String signedDoc = new String(bos.toByteArray());
 
         // Now Verify
-        doc = db.parse(new ByteArrayInputStream(signedDoc.getBytes()));
+        try (InputStream is = new ByteArrayInputStream(signedDoc.getBytes())) {
+            doc = XMLUtils.read(is, false);
+        }
 
         XPathFactory xpf = XPathFactory.newInstance();
         XPath xpath = xpf.newXPath();
@@ -211,7 +218,10 @@ public class CreateSignatureTest extends org.junit.Assert {
     public void testCanonicalizedOctetStream() throws Exception {
         String signedXML = doSign();
 
-        Document doc = db.parse(new ByteArrayInputStream(signedXML.getBytes()));
+        Document doc = null;
+        try (InputStream is = new ByteArrayInputStream(signedXML.getBytes())) {
+            doc = XMLUtils.read(is, false);
+        }
 
         XPathFactory xpf = XPathFactory.newInstance();
         XPath xpath = xpf.newXPath();
@@ -246,10 +256,212 @@ public class CreateSignatureTest extends org.junit.Assert {
         assertTrue(si.verify(false));
     }
 
+    @org.junit.Test
+    public void testSHA256Digest() throws Exception {
+        PrivateKey privateKey = kp.getPrivate();
+        Document doc = XMLUtils.newDocument();
+        doc.appendChild(doc.createComment(" Comment before "));
+        Element root = doc.createElementNS("", "RootElement");
+
+        doc.appendChild(root);
+        root.appendChild(doc.createTextNode("Some simple text\n"));
+
+        Element canonElem =
+            XMLUtils.createElementInSignatureSpace(doc, Constants._TAG_CANONICALIZATIONMETHOD);
+        canonElem.setAttributeNS(
+            null, Constants._ATT_ALGORITHM, Canonicalizer.ALGO_ID_C14N_EXCL_OMIT_COMMENTS
+        );
+
+        SignatureAlgorithm signatureAlgorithm =
+            new SignatureAlgorithm(doc, XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA256);
+        XMLSignature sig =
+            new XMLSignature(doc, null, signatureAlgorithm.getElement(), canonElem);
+
+        root.appendChild(sig.getElement());
+        doc.appendChild(doc.createComment(" Comment after "));
+        Transforms transforms = new Transforms(doc);
+        transforms.addTransform(Transforms.TRANSFORM_ENVELOPED_SIGNATURE);
+        transforms.addTransform(Transforms.TRANSFORM_C14N_WITH_COMMENTS);
+        sig.addDocument("", transforms, MessageDigestAlgorithm.ALGO_ID_DIGEST_SHA256);
+
+        sig.addKeyInfo(kp.getPublic());
+        sig.sign(privateKey);
+
+        ByteArrayOutputStream bos = new ByteArrayOutputStream();
+
+        XMLUtils.outputDOMc14nWithComments(doc, bos);
+        String signedContent = new String(bos.toByteArray());
+
+        doVerify(signedContent);
+    }
+
+    @org.junit.Test
+    public void testSignatureProperties() throws Exception {
+        PrivateKey privateKey = kp.getPrivate();
+        Document doc = XMLUtils.newDocument();
+        Element root = doc.createElementNS("", "RootElement");
+
+        doc.appendChild(root);
+        root.appendChild(doc.createTextNode("Some simple text\n"));
+
+        Element canonElem =
+            XMLUtils.createElementInSignatureSpace(doc, Constants._TAG_CANONICALIZATIONMETHOD);
+        canonElem.setAttributeNS(
+            null, Constants._ATT_ALGORITHM, Canonicalizer.ALGO_ID_C14N_EXCL_OMIT_COMMENTS
+        );
+
+        SignatureAlgorithm signatureAlgorithm =
+            new SignatureAlgorithm(doc, XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA1);
+        XMLSignature sig =
+            new XMLSignature(doc, null, signatureAlgorithm.getElement(), canonElem);
+        String id = "12345";
+        sig.setId(id);
+
+        ObjectContainer object = new ObjectContainer(doc);
+        SignatureProperties signatureProperties = new SignatureProperties(doc);
+        String sigPropertiesId = "54321";
+        signatureProperties.setId(sigPropertiesId);
+        SignatureProperty signatureProperty = new SignatureProperty(doc, "#" + id);
+        signatureProperties.addSignatureProperty(signatureProperty);
+        object.appendChild(signatureProperties.getElement());
+        signatureProperties.getElement().setIdAttributeNS(null, "Id", true);
+        sig.appendObject(object);
+        sig.addDocument("#" + sigPropertiesId);
+
+        root.appendChild(sig.getElement());
+        Transforms transforms = new Transforms(doc);
+        transforms.addTransform(Transforms.TRANSFORM_ENVELOPED_SIGNATURE);
+        transforms.addTransform(Transforms.TRANSFORM_C14N_WITH_COMMENTS);
+        sig.addDocument("", transforms, Constants.ALGO_ID_DIGEST_SHA1);
+
+        sig.addKeyInfo(kp.getPublic());
+        sig.sign(privateKey);
+
+        ByteArrayOutputStream bos = new ByteArrayOutputStream();
+
+        XMLUtils.outputDOMc14nWithComments(doc, bos);
+        String signedContent = new String(bos.toByteArray());
+        doVerify(signedContent);
+    }
+
+    @org.junit.Test
+    public void testAddDuplicateKeyInfo() throws Exception {
+        PrivateKey privateKey = kp.getPrivate();
+        Document doc = XMLUtils.newDocument();
+        Element root = doc.createElementNS("", "RootElement");
+
+        doc.appendChild(root);
+        root.appendChild(doc.createTextNode("Some simple text\n"));
+
+        Element canonElem =
+            XMLUtils.createElementInSignatureSpace(doc, Constants._TAG_CANONICALIZATIONMETHOD);
+        canonElem.setAttributeNS(
+            null, Constants._ATT_ALGORITHM, Canonicalizer.ALGO_ID_C14N_EXCL_OMIT_COMMENTS
+        );
+
+        SignatureAlgorithm signatureAlgorithm =
+            new SignatureAlgorithm(doc, XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA1);
+        XMLSignature sig =
+            new XMLSignature(doc, null, signatureAlgorithm.getElement(), canonElem);
+        String id = "12345";
+        sig.setId(id);
+
+        root.appendChild(sig.getElement());
+        Transforms transforms = new Transforms(doc);
+        transforms.addTransform(Transforms.TRANSFORM_ENVELOPED_SIGNATURE);
+        transforms.addTransform(Transforms.TRANSFORM_C14N_WITH_COMMENTS);
+        sig.addDocument("", transforms, Constants.ALGO_ID_DIGEST_SHA1);
+
+        sig.addKeyInfo(kp.getPublic());
+        sig.sign(privateKey);
+
+        // Add a duplicate (empty) KeyInfo element
+        KeyInfo keyInfo = new KeyInfo(doc);
+        sig.getElement().appendChild(keyInfo.getElement());
+
+        ByteArrayOutputStream bos = new ByteArrayOutputStream();
+
+        XMLUtils.outputDOMc14nWithComments(doc, bos);
+        String signedContent = new String(bos.toByteArray());
+        try {
+            doVerify(signedContent);
+            fail("Failure expected on a duplicate KeyInfo element");
+        } catch (XMLSignatureException ex) {
+            // expected
+        }
+    }
+
+    @org.junit.Test
+    public void testWrongSignatureName() throws Exception {
+        PrivateKey privateKey = kp.getPrivate();
+        Document doc = XMLUtils.newDocument();
+        Element root = doc.createElementNS("", "RootElement");
+
+        doc.appendChild(root);
+        root.appendChild(doc.createTextNode("Some simple text\n"));
+
+        Element canonElem =
+            XMLUtils.createElementInSignatureSpace(doc, Constants._TAG_CANONICALIZATIONMETHOD);
+        canonElem.setAttributeNS(
+            null, Constants._ATT_ALGORITHM, Canonicalizer.ALGO_ID_C14N_EXCL_OMIT_COMMENTS
+        );
+
+        SignatureAlgorithm signatureAlgorithm =
+            new SignatureAlgorithm(doc, XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA1);
+        XMLSignature sig =
+            new XMLSignature(doc, null, signatureAlgorithm.getElement(), canonElem);
+        String id = "12345";
+        sig.setId(id);
+
+        ObjectContainer object = new ObjectContainer(doc);
+        SignatureProperties signatureProperties = new SignatureProperties(doc);
+        String sigPropertiesId = "54321";
+        signatureProperties.setId(sigPropertiesId);
+        SignatureProperty signatureProperty = new SignatureProperty(doc, "#" + id);
+        signatureProperties.addSignatureProperty(signatureProperty);
+        object.appendChild(signatureProperties.getElement());
+        signatureProperties.getElement().setIdAttributeNS(null, "Id", true);
+        sig.appendObject(object);
+        sig.addDocument("#" + sigPropertiesId);
+
+        root.appendChild(sig.getElement());
+
+        sig.addKeyInfo(kp.getPublic());
+        sig.sign(privateKey);
+
+        ByteArrayOutputStream bos = new ByteArrayOutputStream();
+
+        XMLUtils.outputDOMc14nWithComments(doc, bos);
+        String signedContent = new String(bos.toByteArray());
+        // Now change the Signature Element to be "SomeSignature" instead
+        signedContent = signedContent.replaceAll("ds:Signature ", "ds:SomeSignature ");
+        signedContent = signedContent.replaceAll("</ds:Signature>", "</ds:SomeSignature>");
+
+        // Verify the signature
+        Document doc2 = null;
+        try (InputStream is = new ByteArrayInputStream(signedContent.getBytes())) {
+            doc2 = XMLUtils.read(is, false);
+        }
+
+        XPathFactory xpf = XPathFactory.newInstance();
+        XPath xpath = xpf.newXPath();
+        xpath.setNamespaceContext(new DSNamespaceContext());
+
+        String expression = "//ds:SomeSignature[1]";
+        Element sigElement =
+            (Element) xpath.evaluate(expression, doc2, XPathConstants.NODE);
+
+        try {
+            new XMLSignature(sigElement, "");
+            fail("Failure expected on an incorrect Signature element name");
+        } catch (XMLSignatureException ex) {
+            // expected
+        }
+    }
 
     private String doSign() throws Exception {
         PrivateKey privateKey = kp.getPrivate();
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         doc.appendChild(doc.createComment(" Comment before "));
         Element root = doc.createElementNS("", "RootElement");
 
@@ -294,7 +506,7 @@ public class CreateSignatureTest extends org.junit.Assert {
         }
         ks.load(fis, "changeit".toCharArray());
         PrivateKey privateKey = (PrivateKey) ks.getKey("mullan", "changeit".toCharArray());
-        Document doc = db.newDocument();
+        Document doc = XMLUtils.newDocument();
         X509Certificate signingCert = (X509Certificate) ks.getCertificate("mullan");
         doc.appendChild(doc.createComment(" Comment before "));
         Element root = doc.createElementNS("", "RootElement");
@@ -331,7 +543,10 @@ public class CreateSignatureTest extends org.junit.Assert {
     }
 
     private void doVerify(String signedXML) throws Exception {
-        Document doc = db.parse(new ByteArrayInputStream(signedXML.getBytes()));
+        Document doc = null;
+        try (InputStream is = new ByteArrayInputStream(signedXML.getBytes())) {
+            doc = XMLUtils.read(is, false);
+        }
 
         XPathFactory xpf = XPathFactory.newInstance();
         XPath xpath = xpf.newXPath();
