@@ -37,6 +37,8 @@ import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 
+import static org.junit.Assert.*;
+
 import java.io.*;
 import java.net.URL;
 import java.util.ArrayList;
@@ -45,10 +47,8 @@ import java.util.List;
 import java.util.Map;
 
 /**
- * @author $Author: coheigea $
- * @version $Revision: 1721336 $ $Date: 2015-12-22 11:45:18 +0100 (Tue, 22 Dec 2015) $
  */
-public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
+public class Canonicalizer20010315ExclusiveTest {
 
     private XMLInputFactory xmlInputFactory;
 
@@ -92,9 +92,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         boolean equals = java.security.MessageDigest.isEqual(reference, baos.toByteArray());
 
         if (!equals) {
-            System.out.println("Expected:\n" + new String(reference, "UTF-8"));
+            System.out.println("Expected:\n" + new String(reference, java.nio.charset.StandardCharsets.UTF_8));
             System.out.println("");
-            System.out.println("Got:\n" + new String(baos.toByteArray(), "UTF-8"));
+            System.out.println("Got:\n" + new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8));
         }
 
         assertTrue(equals);
@@ -119,9 +119,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         boolean equals = java.security.MessageDigest.isEqual(reference, baos.toByteArray());
 
         if (!equals) {
-            System.out.println("Expected:\n" + new String(reference, "UTF-8"));
+            System.out.println("Expected:\n" + new String(reference, java.nio.charset.StandardCharsets.UTF_8));
             System.out.println("");
-            System.out.println("Got:\n" + new String(baos.toByteArray(), "UTF-8"));
+            System.out.println("Got:\n" + new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8));
         }
 
         assertTrue(equals);
@@ -146,9 +146,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         boolean equals = java.security.MessageDigest.isEqual(reference, baos.toByteArray());
 
         if (!equals) {
-            System.out.println("Expected:\n" + new String(reference, "UTF-8"));
+            System.out.println("Expected:\n" + new String(reference, java.nio.charset.StandardCharsets.UTF_8));
             System.out.println("");
-            System.out.println("Got:\n" + new String(baos.toByteArray(), "UTF-8"));
+            System.out.println("Got:\n" + new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8));
         }
 
         assertTrue(equals);
@@ -173,9 +173,9 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         boolean equals = java.security.MessageDigest.isEqual(reference, baos.toByteArray());
 
         if (!equals) {
-            System.out.println("Expected:\n" + new String(reference, "UTF-8"));
+            System.out.println("Expected:\n" + new String(reference, java.nio.charset.StandardCharsets.UTF_8));
             System.out.println("");
-            System.out.println("Got:\n" + new String(baos.toByteArray(), "UTF-8"));
+            System.out.println("Got:\n" + new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8));
         }
         assertTrue(equals);
     }
@@ -210,20 +210,20 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</env:Body>";
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        List<String> inclusiveNamespaces = new ArrayList<String>();
+        List<String> inclusiveNamespaces = new ArrayList<>();
         inclusiveNamespaces.add("env");
         inclusiveNamespaces.add("ns0");
         inclusiveNamespaces.add("xsi");
         inclusiveNamespaces.add("wsu");
         Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-        Map<String, Object> transformerProperties = new HashMap<String, Object>();
+        Map<String, Object> transformerProperties = new HashMap<>();
         transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
         c.setProperties(transformerProperties);
         c.setOutputStream(baos);
 
         canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-        assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+        assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
     }
 
     /**
@@ -233,7 +233,7 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
      */
     @org.junit.Test
     public void test24Aexcl() throws Exception {
-        Document doc = XMLUtils.createDocumentBuilder(false).newDocument();
+        Document doc = XMLUtils.newDocument();
         Element local = doc.createElementNS("foo:bar", "dsig:local");
         Element test = doc.createElementNS("http://example.net", "etsi:test");
         Element elem2 = doc.createElementNS("http://example.net", "etsi:elem2");
@@ -250,10 +250,10 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
         t.transform(new DOMSource(doc), streamResult);
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        List<String> inclusiveNamespaces = new ArrayList<String>();
+        List<String> inclusiveNamespaces = new ArrayList<>();
         Canonicalizer20010315_ExclWithCommentsTransformer c =
                 new Canonicalizer20010315_ExclWithCommentsTransformer();
-        Map<String, Object> transformerProperties = new HashMap<String, Object>();
+        Map<String, Object> transformerProperties = new HashMap<>();
         transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
         c.setProperties(transformerProperties);
         c.setOutputStream(baos);
@@ -302,32 +302,32 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
 
         {
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("#default");
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
         }
 
         {
             //exactly the same outcome is expected if #default is not set:
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
         }
     }
 
@@ -378,30 +378,30 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
 
         {
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("#default");
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML1);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML1);
         }
         {
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML2);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML2);
         }
     }
 
@@ -440,31 +440,31 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
 
         {
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("#default");
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
         }
         {
             //exactly the same outcome is expected if #default is not set:
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
         }
     }
 
@@ -503,31 +503,31 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
 
         {
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("#default");
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
         }
         {
             //exactly the same outcome is expected if #default is not set:
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            List<String> inclusiveNamespaces = new ArrayList<String>();
+            List<String> inclusiveNamespaces = new ArrayList<>();
             inclusiveNamespaces.add("xsi");
             Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-            Map<String, Object> transformerProperties = new HashMap<String, Object>();
+            Map<String, Object> transformerProperties = new HashMap<>();
             transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
             c.setProperties(transformerProperties);
             c.setOutputStream(baos);
             canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-            assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+            assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
         }
     }
 
@@ -564,17 +564,17 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</env:Body>";
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        List<String> inclusiveNamespaces = new ArrayList<String>();
+        List<String> inclusiveNamespaces = new ArrayList<>();
         inclusiveNamespaces.add("#default");
         Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-        Map<String, Object> transformerProperties = new HashMap<String, Object>();
+        Map<String, Object> transformerProperties = new HashMap<>();
         transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
         transformerProperties.put(Canonicalizer20010315_Excl.PROPAGATE_DEFAULT_NAMESPACE, Boolean.TRUE);
         c.setProperties(transformerProperties);
         c.setOutputStream(baos);
         canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-        assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+        assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
     }
 
     @org.junit.Test
@@ -606,17 +606,17 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</env:Body>";
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        List<String> inclusiveNamespaces = new ArrayList<String>();
+        List<String> inclusiveNamespaces = new ArrayList<>();
         inclusiveNamespaces.add("#default");
         Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-        Map<String, Object> transformerProperties = new HashMap<String, Object>();
+        Map<String, Object> transformerProperties = new HashMap<>();
         transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
         transformerProperties.put(Canonicalizer20010315_Excl.PROPAGATE_DEFAULT_NAMESPACE, Boolean.TRUE);
         c.setProperties(transformerProperties);
         c.setOutputStream(baos);
         canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-        assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+        assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
     }
 
     @org.junit.Test
@@ -648,17 +648,17 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</env:Body>";
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        List<String> inclusiveNamespaces = new ArrayList<String>();
+        List<String> inclusiveNamespaces = new ArrayList<>();
         inclusiveNamespaces.add("#default");
         Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-        Map<String, Object> transformerProperties = new HashMap<String, Object>();
+        Map<String, Object> transformerProperties = new HashMap<>();
         transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
         transformerProperties.put(Canonicalizer20010315_Excl.PROPAGATE_DEFAULT_NAMESPACE, Boolean.TRUE);
         c.setProperties(transformerProperties);
         c.setOutputStream(baos);
         canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-        assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+        assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
     }
 
     @org.junit.Test
@@ -690,17 +690,17 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</env:Body>";
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        List<String> inclusiveNamespaces = new ArrayList<String>();
+        List<String> inclusiveNamespaces = new ArrayList<>();
         inclusiveNamespaces.add("#default");
         Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-        Map<String, Object> transformerProperties = new HashMap<String, Object>();
+        Map<String, Object> transformerProperties = new HashMap<>();
         transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
         transformerProperties.put(Canonicalizer20010315_Excl.PROPAGATE_DEFAULT_NAMESPACE, Boolean.TRUE);
         c.setProperties(transformerProperties);
         c.setOutputStream(baos);
         canonicalize(c, new StringReader(XML), new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
 
-        assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+        assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
     }
 
     @org.junit.Test
@@ -727,17 +727,17 @@ public class Canonicalizer20010315ExclusiveTest extends org.junit.Assert {
                         + "</ns0:Ping>";
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        List<String> inclusiveNamespaces = new ArrayList<String>();
+        List<String> inclusiveNamespaces = new ArrayList<>();
         inclusiveNamespaces.add("#default");
         Canonicalizer20010315_ExclOmitCommentsTransformer c = new Canonicalizer20010315_ExclOmitCommentsTransformer();
-        Map<String, Object> transformerProperties = new HashMap<String, Object>();
+        Map<String, Object> transformerProperties = new HashMap<>();
         transformerProperties.put(Canonicalizer20010315_Excl.INCLUSIVE_NAMESPACES_PREFIX_LIST, inclusiveNamespaces);
         transformerProperties.put(Canonicalizer20010315_Excl.PROPAGATE_DEFAULT_NAMESPACE, Boolean.TRUE);
         c.setProperties(transformerProperties);
         c.setOutputStream(baos);
         canonicalize(c, new StringReader(XML), new QName("http://xmlsoap.org/Ping", "Ping"));
 
-        assertEquals(new String(baos.toByteArray(), "UTF-8"), c14nXML);
+        assertEquals(new String(baos.toByteArray(), java.nio.charset.StandardCharsets.UTF_8), c14nXML);
     }
 
     private void canonicalize(
