@@ -31,7 +31,6 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.UUID;
 
-import javax.xml.parsers.DocumentBuilder;
 import javax.xml.stream.XMLStreamReader;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
@@ -56,8 +55,6 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
 /**
- * @author $Author: coheigea $
- * @version $Revision: 1720201 $ $Date: 2015-12-15 18:13:17 +0100 (Tue, 15 Dec 2015) $
  */
 public class SignatureVerificationReferenceURIResolverTest extends AbstractSignatureVerificationTest {
 
@@ -67,8 +64,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InputStream sourceDocument =
                 this.getClass().getClassLoader().getResourceAsStream(
                         "ie/baltimore/merlin-examples/merlin-xmlenc-five/plaintext.xml");
-        DocumentBuilder builder = XMLUtils.createDocumentBuilder(false);
-        Document document = builder.parse(sourceDocument);
+        Document document = XMLUtils.read(sourceDocument, false);
 
         // Set up the Key
         KeyStore keyStore = KeyStore.getInstance("jks");
@@ -80,7 +76,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         X509Certificate cert = (X509Certificate) keyStore.getCertificate("transmitter");
 
         // Sign using DOM
-        List<String> localNames = new ArrayList<String>();
+        List<String> localNames = new ArrayList<>();
         localNames.add("PaymentInfo");
         File file = new File(BASEDIR +
                 "/src/test/resources/ie/baltimore/merlin-examples/merlin-xmlenc-five/plaintext.xml").getCanonicalFile();
@@ -92,7 +88,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
                 false
         );
 
-        List<ReferenceInfo> referenceInfos = new ArrayList<ReferenceInfo>();
+        List<ReferenceInfo> referenceInfos = new ArrayList<>();
         referenceInfos.add(referenceInfo);
 
         XMLSignature sig = signUsingDOM(
@@ -110,8 +106,11 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         javax.xml.transform.Transformer transformer = transformerFactory.newTransformer();
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         transformer.transform(new DOMSource(document), new StreamResult(baos));
-        final XMLStreamReader xmlStreamReader =
-                xmlInputFactory.createXMLStreamReader(new ByteArrayInputStream(baos.toByteArray()));
+
+        XMLStreamReader xmlStreamReader = null;
+        try (InputStream is = new ByteArrayInputStream(baos.toByteArray())) {
+           xmlStreamReader = xmlInputFactory.createXMLStreamReader(is);
+        }
 
         // Verify signature
         XMLSecurityProperties properties = new XMLSecurityProperties();
@@ -121,7 +120,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
 
         try {
             TestUtils.switchAllowNotSameDocumentReferences(true);
-            StAX2DOM.readDoc(XMLUtils.createDocumentBuilder(false), securityStreamReader);
+            StAX2DOM.readDoc(securityStreamReader);
         } finally {
             TestUtils.switchAllowNotSameDocumentReferences(false);
         }
@@ -133,8 +132,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InputStream sourceDocument =
                 this.getClass().getClassLoader().getResourceAsStream(
                         "ie/baltimore/merlin-examples/merlin-xmlenc-five/plaintext.xml");
-        DocumentBuilder builder = XMLUtils.createDocumentBuilder(false);
-        Document document = builder.parse(sourceDocument);
+        Document document = XMLUtils.read(sourceDocument, false);
 
         // Set up the Key
         KeyStore keyStore = KeyStore.getInstance("jks");
@@ -146,7 +144,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         X509Certificate cert = (X509Certificate) keyStore.getCertificate("transmitter");
 
         // Sign using DOM
-        List<String> localNames = new ArrayList<String>();
+        List<String> localNames = new ArrayList<>();
         localNames.add("PaymentInfo");
 
         File file = new File(BASEDIR +
@@ -159,7 +157,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
                 true
         );
 
-        List<ReferenceInfo> referenceInfos = new ArrayList<ReferenceInfo>();
+        List<ReferenceInfo> referenceInfos = new ArrayList<>();
         referenceInfos.add(referenceInfo);
 
         XMLSignature sig = signUsingDOM(
@@ -177,8 +175,11 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         javax.xml.transform.Transformer transformer = transformerFactory.newTransformer();
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         transformer.transform(new DOMSource(document), new StreamResult(baos));
-        final XMLStreamReader xmlStreamReader =
-                xmlInputFactory.createXMLStreamReader(new ByteArrayInputStream(baos.toByteArray()));
+
+        XMLStreamReader xmlStreamReader = null;
+        try (InputStream is = new ByteArrayInputStream(baos.toByteArray())) {
+           xmlStreamReader = xmlInputFactory.createXMLStreamReader(is);
+        }
 
         // Verify signature
         XMLSecurityProperties properties = new XMLSecurityProperties();
@@ -188,7 +189,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
 
         try {
             TestUtils.switchAllowNotSameDocumentReferences(true);
-            StAX2DOM.readDoc(XMLUtils.createDocumentBuilder(false), securityStreamReader);
+            StAX2DOM.readDoc(securityStreamReader);
         } finally {
             TestUtils.switchAllowNotSameDocumentReferences(false);
         }
@@ -212,8 +213,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
             InputStream sourceDocument =
                     this.getClass().getClassLoader().getResourceAsStream(
                             "ie/baltimore/merlin-examples/merlin-xmlenc-five/plaintext.xml");
-            DocumentBuilder builder = XMLUtils.createDocumentBuilder(false);
-            Document document = builder.parse(sourceDocument);
+            Document document = XMLUtils.read(sourceDocument, false);
 
             // Set up the Key
             KeyStore keyStore = KeyStore.getInstance("jks");
@@ -225,7 +225,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
             X509Certificate cert = (X509Certificate) keyStore.getCertificate("transmitter");
 
             // Sign using DOM
-            List<String> localNames = new ArrayList<String>();
+            List<String> localNames = new ArrayList<>();
             localNames.add("PaymentInfo");
 
             ReferenceInfo referenceInfo = new ReferenceInfo(
@@ -235,7 +235,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
                     true
             );
 
-            List<ReferenceInfo> referenceInfos = new ArrayList<ReferenceInfo>();
+            List<ReferenceInfo> referenceInfos = new ArrayList<>();
             referenceInfos.add(referenceInfo);
 
             XMLSignature sig = signUsingDOM(
@@ -254,8 +254,11 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
             javax.xml.transform.Transformer transformer = transformerFactory.newTransformer();
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
             transformer.transform(new DOMSource(document), new StreamResult(baos));
-            final XMLStreamReader xmlStreamReader =
-                    xmlInputFactory.createXMLStreamReader(new ByteArrayInputStream(baos.toByteArray()));
+
+            XMLStreamReader xmlStreamReader = null;
+            try (InputStream is = new ByteArrayInputStream(baos.toByteArray())) {
+               xmlStreamReader = xmlInputFactory.createXMLStreamReader(is);
+            }
 
             // Verify signature
             XMLSecurityProperties properties = new XMLSecurityProperties();
@@ -263,7 +266,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
             InboundXMLSec inboundXMLSec = XMLSec.getInboundWSSec(properties);
             XMLStreamReader securityStreamReader = inboundXMLSec.processInMessage(xmlStreamReader);
 
-            StAX2DOM.readDoc(XMLUtils.createDocumentBuilder(false), securityStreamReader);
+            StAX2DOM.readDoc(securityStreamReader);
         } finally {
             TestUtils.switchAllowNotSameDocumentReferences(false);
             HttpRequestRedirectorProxy.stopHttpEngine();
@@ -276,8 +279,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InputStream sourceDocument =
                 this.getClass().getClassLoader().getResourceAsStream(
                         "ie/baltimore/merlin-examples/merlin-xmlenc-five/plaintext.xml");
-        DocumentBuilder builder = XMLUtils.createDocumentBuilder(false);
-        Document document = builder.parse(sourceDocument);
+        Document document = XMLUtils.read(sourceDocument, false);
 
         // Set up the Key
         KeyStore keyStore = KeyStore.getInstance("jks");
@@ -301,7 +303,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         elementToSign.setIdAttributeNS(null, "Id", true);
 
         // Sign using DOM
-        List<String> localNames = new ArrayList<String>();
+        List<String> localNames = new ArrayList<>();
         localNames.add("PaymentInfo");
 
         ReferenceInfo referenceInfo = new ReferenceInfo(
@@ -311,7 +313,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
                 false
         );
 
-        List<ReferenceInfo> referenceInfos = new ArrayList<ReferenceInfo>();
+        List<ReferenceInfo> referenceInfos = new ArrayList<>();
         referenceInfos.add(referenceInfo);
 
         XMLSignature sig = signUsingDOM(
@@ -329,8 +331,11 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         javax.xml.transform.Transformer transformer = transformerFactory.newTransformer();
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         transformer.transform(new DOMSource(document), new StreamResult(baos));
-        final XMLStreamReader xmlStreamReader =
-                xmlInputFactory.createXMLStreamReader(new ByteArrayInputStream(baos.toByteArray()));
+
+        XMLStreamReader xmlStreamReader = null;
+        try (InputStream is = new ByteArrayInputStream(baos.toByteArray())) {
+           xmlStreamReader = xmlInputFactory.createXMLStreamReader(is);
+        }
 
         // Verify signature
         XMLSecurityProperties properties = new XMLSecurityProperties();
@@ -338,7 +343,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InboundXMLSec inboundXMLSec = XMLSec.getInboundWSSec(properties);
         XMLStreamReader securityStreamReader = inboundXMLSec.processInMessage(xmlStreamReader);
 
-        StAX2DOM.readDoc(XMLUtils.createDocumentBuilder(false), securityStreamReader);
+        StAX2DOM.readDoc(securityStreamReader);
     }
 
     @Test
@@ -347,8 +352,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InputStream sourceDocument =
                 this.getClass().getClassLoader().getResourceAsStream(
                         "ie/baltimore/merlin-examples/merlin-xmlenc-five/plaintext.xml");
-        DocumentBuilder builder = XMLUtils.createDocumentBuilder(false);
-        Document document = builder.parse(sourceDocument);
+        Document document = XMLUtils.read(sourceDocument, false);
 
         // Set up the Key
         KeyStore keyStore = KeyStore.getInstance("jks");
@@ -372,7 +376,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         elementToSign.setIdAttributeNS(null, "Id", true);
 
         // Sign using DOM
-        List<String> localNames = new ArrayList<String>();
+        List<String> localNames = new ArrayList<>();
         localNames.add("PaymentInfo");
 
         ReferenceInfo referenceInfo = new ReferenceInfo(
@@ -382,7 +386,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
                 false
         );
 
-        List<ReferenceInfo> referenceInfos = new ArrayList<ReferenceInfo>();
+        List<ReferenceInfo> referenceInfos = new ArrayList<>();
         referenceInfos.add(referenceInfo);
 
         XMLSignature sig = signUsingDOM(
@@ -400,8 +404,11 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         javax.xml.transform.Transformer transformer = transformerFactory.newTransformer();
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         transformer.transform(new DOMSource(document), new StreamResult(baos));
-        final XMLStreamReader xmlStreamReader =
-                xmlInputFactory.createXMLStreamReader(new ByteArrayInputStream(baos.toByteArray()));
+
+        XMLStreamReader xmlStreamReader = null;
+        try (InputStream is = new ByteArrayInputStream(baos.toByteArray())) {
+           xmlStreamReader = xmlInputFactory.createXMLStreamReader(is);
+        }
 
         // Verify signature
         XMLSecurityProperties properties = new XMLSecurityProperties();
@@ -409,7 +416,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InboundXMLSec inboundXMLSec = XMLSec.getInboundWSSec(properties);
         XMLStreamReader securityStreamReader = inboundXMLSec.processInMessage(xmlStreamReader);
 
-        StAX2DOM.readDoc(XMLUtils.createDocumentBuilder(false), securityStreamReader);
+        StAX2DOM.readDoc(securityStreamReader);
     }
 
     @Test
@@ -418,8 +425,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InputStream sourceDocument =
                 this.getClass().getClassLoader().getResourceAsStream(
                         "ie/baltimore/merlin-examples/merlin-xmlenc-five/plaintext.xml");
-        DocumentBuilder builder = XMLUtils.createDocumentBuilder(false);
-        Document document = builder.parse(sourceDocument);
+        Document document = XMLUtils.read(sourceDocument, false);
 
         // Set up the Key
         KeyStore keyStore = KeyStore.getInstance("jks");
@@ -431,7 +437,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         X509Certificate cert = (X509Certificate) keyStore.getCertificate("transmitter");
 
         // Sign using DOM
-        List<String> localNames = new ArrayList<String>();
+        List<String> localNames = new ArrayList<>();
 
         ReferenceInfo referenceInfo = new ReferenceInfo(
                 "#xpointer(/)",
@@ -443,7 +449,7 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
                 false
         );
 
-        List<ReferenceInfo> referenceInfos = new ArrayList<ReferenceInfo>();
+        List<ReferenceInfo> referenceInfos = new ArrayList<>();
         referenceInfos.add(referenceInfo);
 
         XMLSignature sig = signUsingDOM(
@@ -464,8 +470,10 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
 
         //System.out.println(baos.toString());
 
-        final XMLStreamReader xmlStreamReader =
-                xmlInputFactory.createXMLStreamReader(new ByteArrayInputStream(baos.toByteArray()));
+        XMLStreamReader xmlStreamReader = null;
+        try (InputStream is = new ByteArrayInputStream(baos.toByteArray())) {
+           xmlStreamReader = xmlInputFactory.createXMLStreamReader(is);
+        }
 
         // Verify signature
         XMLSecurityProperties properties = new XMLSecurityProperties();
@@ -473,6 +481,6 @@ public class SignatureVerificationReferenceURIResolverTest extends AbstractSigna
         InboundXMLSec inboundXMLSec = XMLSec.getInboundWSSec(properties);
         XMLStreamReader securityStreamReader = inboundXMLSec.processInMessage(xmlStreamReader);
 
-        StAX2DOM.readDoc(XMLUtils.createDocumentBuilder(false), securityStreamReader);
+        StAX2DOM.readDoc(securityStreamReader);
     }
 }
